#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/15 0015
# @Author  : justin.郑 3907721@qq.com
# @File    : cons.py
# @Desc    : 电影数据 配置文件

headers = {
    "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.88 Safari/537.36",
}

BOX = 'boxOffice'

MOVIE_BOX = 'http://www.cbooo.cn/%s/GetHourBoxOffice?d=%s'



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/21 0021
# @Author  : justin.郑 3907721@qq.com
# @File    : covid.py
# @Desc    : 获取疫情数据
 
import json
import time
import demjson
import jsonpath
import requests
import pandas as pd
from io import BytesIO
from PIL import Image
from bs4 import BeautifulSoup


def covid_163(indicator="实时"):
    """
    网易-新冠状病毒
    https://news.163.com/special/epidemic/?spssid=93326430940df93a37229666dfbc4b96&spsw=4&spss=other&#map_block
    https://news.163.com/special/epidemic/?spssid=93326430940df93a37229666dfbc4b96&spsw=4&spss=other&
    :return: 返回指定 indicator 的数据
    :rtype: pandas.DataFrame
    """
    url = "https://c.m.163.com/ug/api/wuhan/app/data/list-total"
    headers = {
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.130 Safari/537.36",
    }
    payload = {
        "t": int(time.time() * 1000),
    }
    r = requests.get(url, params=payload, headers=headers)
    data_json = r.json()
    # data info
    url = "https://news.163.com/special/epidemic/"
    r = requests.get(url, headers=headers)
    soup = BeautifulSoup(r.text, "lxml")
    data_info_df = pd.DataFrame(
        [
            item.text.strip().split(".")[1]
            for item in soup.find("div", attrs={"class": "data_tip_pop_text"}).find_all(
                "p"
            )
        ]
    )
    data_info_df.columns = ["info"]

    # 中国历史时点数据
    hist_today_df = pd.DataFrame(
        [item["today"] for item in data_json["data"]["chinaDayList"]],
        index=[item["date"] for item in data_json["data"]["chinaDayList"]],
    )

    # 中国历史累计数据
    hist_total_df = pd.DataFrame(
        [item["total"] for item in data_json["data"]["chinaDayList"]],
        index=[item["date"] for item in data_json["data"]["chinaDayList"]],
    )

    # 中国实时数据
    current_df = pd.DataFrame.from_dict(data_json["data"]["chinaTotal"])

    # 世界历史时点数据
    outside_today_df = pd.DataFrame(
        [item["today"] for item in data_json["data"]["areaTree"]],
        index=[item["name"] for item in data_json["data"]["areaTree"]],
    )

    # 世界历史累计数据
    outside_total_df = pd.DataFrame(
        [item["total"] for item in data_json["data"]["areaTree"]],
        index=[item["name"] for item in data_json["data"]["areaTree"]],
    )

    # 全球所有国家及地区时点数据
    all_world_today_df = pd.DataFrame(
        jsonpath.jsonpath(data_json["data"]["areaTree"], "$..today"),
        index=jsonpath.jsonpath(data_json["data"]["areaTree"], "$..name"),
    )

    # 全球所有国家及地区累计数据
    all_world_total_df = pd.DataFrame(
        jsonpath.jsonpath(data_json["data"]["areaTree"], "$..total"),
        index=jsonpath.jsonpath(data_json["data"]["areaTree"], "$..name"),
    )

    # 中国各地区时点数据
    area_total_df = pd.DataFrame(
        [item["total"] for item in data_json["data"]["areaTree"][0]["children"]],
        index=[item["name"] for item in data_json["data"]["areaTree"][0]["children"]],
    )

    # 中国各地区累计数据
    area_today_df = pd.DataFrame(
        [item["today"] for item in data_json["data"]["areaTree"][0]["children"]],
        index=[item["name"] for item in data_json["data"]["areaTree"][0]["children"]],
    )

    # 疫情学术进展
    url_article = "https://vip.open.163.com/api/cms/topic/list"
    payload_article = {
        "topicid": "00019NGQ",
        "listnum": "1000",
        "liststart": "0",
        "pointstart": "0",
        "pointend": "255",
        "useproperty": "true",
    }
    r_article = requests.get(url_article, params=payload_article)
    article_df = pd.DataFrame(r_article.json()["data"]).iloc[:, 1:]

    # 咨询
    url_info = "https://ent.163.com/special/00035080/virus_report_data.js"
    payload_info = {
        "_": int(time.time() * 1000),
        "callback": "callback",
    }
    r_info = requests.get(url_info, params=payload_info, headers=headers)
    data_info_text = r_info.text
    data_info_json = demjson.decode(data_info_text.strip(" callback(")[:-1])

    if indicator == "数据说明":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return data_info_df

    if indicator == "中国实时数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return current_df

    if indicator == "中国历史时点数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return hist_today_df

    if indicator == "中国历史累计数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return hist_total_df

    if indicator == "世界历史时点数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return outside_today_df

    if indicator == "世界历史累计数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return outside_total_df

    if indicator == "全球所有国家及地区时点数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return all_world_today_df

    elif indicator == "全球所有国家及地区累计数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return all_world_total_df

    elif indicator == "中国各地区时点数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return area_today_df

    elif indicator == "中国各地区累计数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return area_total_df

    elif indicator == "疫情学术进展":
        return article_df

    elif indicator == "实时资讯新闻播报":
        return pd.DataFrame(data_info_json["list"])

    elif indicator == "实时医院新闻播报":
        return pd.DataFrame(data_info_json["hospital"])

    elif indicator == "前沿知识":
        return pd.DataFrame(data_info_json["papers"])

    elif indicator == "权威发布":
        return pd.DataFrame(data_info_json["power"])

    elif indicator == "滚动新闻":
        return pd.DataFrame(data_info_json["scrollNews"])


def covid_dxy(indicator="湖北"):
    """
    20200315-丁香园接口更新分为国内和国外
    丁香园-全国统计-info
    丁香园-分地区统计-data
    丁香园-全国发热门诊一览表-hospital
    丁香园-全国新闻-news
    :param indicator: ["info", "data", "hospital", "news"]
    :type indicator: str
    :return: 返回指定 indicator 的数据
    :rtype: pandas.DataFrame
    """
    url = "https://3g.dxy.cn/newh5/view/pneumonia"
    r = requests.get(url)
    r.encoding = "utf-8"
    soup = BeautifulSoup(r.text, "lxml")
    # news-china
    text_data_news = str(
        soup.find_all("script", attrs={"id": "getTimelineServiceundefined"})
    )
    temp_json = text_data_news[
        text_data_news.find("= [{") + 2 : text_data_news.rfind("}catch")
    ]
    if temp_json:
        json_data = pd.DataFrame(json.loads(temp_json))
        chinese_news = json_data[
            ["title", "summary", "infoSource", "provinceName", "sourceUrl"]
        ]

    # news-foreign
    text_data_news = str(soup.find_all("script", attrs={"id": "getTimelineService2"}))
    temp_json = text_data_news[
        text_data_news.find("= [{") + 2 : text_data_news.rfind("}catch")
    ]
    json_data = pd.DataFrame(json.loads(temp_json))
    foreign_news = json_data

    # data-domestic
    data_text = str(soup.find("script", attrs={"id": "getAreaStat"}))
    data_text_json = json.loads(
        data_text[data_text.find("= [{") + 2 : data_text.rfind("catch") - 1]
    )
    big_df = pd.DataFrame()
    for i, p in enumerate(jsonpath.jsonpath(data_text_json, "$..provinceName")):
        temp_df = pd.DataFrame(jsonpath.jsonpath(data_text_json, "$..cities")[i])
        temp_df["province"] = p
        big_df = big_df.append(temp_df, ignore_index=True)
    domestic_city_df = big_df

    data_df = pd.DataFrame(data_text_json).iloc[:, :7]
    data_df.columns = ["地区", "地区简称", "现存确诊", "累计确诊", "-", "治愈", "死亡"]
    domestic_province_df = data_df[["地区", "地区简称", "现存确诊", "累计确诊", "治愈", "死亡"]]
    # data-global
    data_text = str(
        soup.find("script", attrs={"id": "getListByCountryTypeService2true"})
    )
    data_text_json = json.loads(
        data_text[data_text.find("= [{") + 2: data_text.rfind("catch") - 1]
    )
    global_df = pd.DataFrame(data_text_json)

    # info
    dxy_static = soup.find(attrs={"id": "getStatisticsService"}).get_text()
    data_json = json.loads(
        dxy_static[dxy_static.find("= {") + 2 : dxy_static.rfind("}c")]
    )
    china_statistics = pd.DataFrame(
        [
            time.strftime(
                "%Y-%m-%d %H:%M:%S", time.localtime(data_json["modifyTime"] / 1000)
            ),
            data_json["currentConfirmedCount"],
            data_json["confirmedCount"],
            data_json["suspectedCount"],
            data_json["curedCount"],
            data_json["deadCount"],
            data_json["seriousCount"],
            data_json["suspectedIncr"],
            data_json["currentConfirmedIncr"],
            data_json["confirmedIncr"],
            data_json["curedIncr"],
            data_json["deadIncr"],
            data_json["seriousIncr"],
        ],
        index=[
            "数据发布时间",
            "现存确诊",
            "累计确诊",
            "境外输入",
            "累计治愈",
            "累计死亡",
            "现存重症",
            "境外输入较昨日",
            "现存确诊较昨日",
            "累计确诊较昨日",
            "累计治愈较昨日",
            "累计死亡较昨日",
            "现存重症较昨日",
        ],
        columns=["info"],
    )
    foreign_statistics = pd.DataFrame.from_dict(
        data_json["foreignStatistics"], orient="index"
    )
    global_statistics = pd.DataFrame.from_dict(
        data_json["globalStatistics"], orient="index"
    )
    # hospital
    url = (
        "https://assets.dxycdn.com/gitrepo/tod-assets/output/default/pneumonia/index.js"
    )
    payload = {"t": str(int(time.time()))}
    r = requests.get(url, params=payload)
    hospital_df = pd.read_html(r.text)[0].iloc[:, :-1]

    if indicator == "中国疫情分省统计详情":
        return domestic_province_df
    if indicator == "中国疫情分市统计详情":
        return domestic_city_df
    elif indicator == "全球疫情分国家统计详情":
        return global_df
    elif indicator == "中国疫情实时统计":
        return china_statistics
    elif indicator == "国外疫情实时统计":
        return foreign_statistics
    elif indicator == "全球疫情实时统计":
        return global_statistics
    elif indicator == "中国疫情防控医院":
        return hospital_df
    elif indicator == "实时播报":
        return chinese_news

    elif indicator == "中国-新增疑似-新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["quanguoTrendChart"][0]["imgUrl"]).content)
        )
        img_file.show()
    elif indicator == "中国-现存确诊-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["quanguoTrendChart"][1]["imgUrl"]).content)
        )
        img_file.show()
    elif indicator == "中国-现存疑似-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["quanguoTrendChart"][2]["imgUrl"]).content)
        )
        img_file.show()
    elif indicator == "中国-治愈-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["quanguoTrendChart"][3]["imgUrl"]).content)
        )
        img_file.show()
    elif indicator == "中国-死亡-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["quanguoTrendChart"][4]["imgUrl"]).content)
        )
        img_file.show()

    elif indicator == "中国-非湖北新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["hbFeiHbTrendChart"][0]["imgUrl"]).content)
        )
        img_file.show()
    elif indicator == "中国-湖北新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["hbFeiHbTrendChart"][1]["imgUrl"]).content)
        )
        img_file.show()
    elif indicator == "中国-湖北现存确诊-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["hbFeiHbTrendChart"][2]["imgUrl"]).content)
        )
        img_file.show()
    elif indicator == "中国-非湖北现存确诊-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["hbFeiHbTrendChart"][3]["imgUrl"]).content)
        )
        img_file.show()
    elif indicator == "中国-治愈-死亡-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["hbFeiHbTrendChart"][4]["imgUrl"]).content)
        )
        img_file.show()

    elif indicator == "国外-国外新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["foreignTrendChart"][0]["imgUrl"]).content)
        )
        img_file.show()
    elif indicator == "国外-国外累计确诊-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["foreignTrendChart"][1]["imgUrl"]).content)
        )
        img_file.show()
    elif indicator == "国外-国外死亡-趋势图":
        img_file = Image.open(
            BytesIO(requests.get(data_json["foreignTrendChart"][2]["imgUrl"]).content)
        )
        img_file.show()

    elif indicator == "国外-重点国家新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(
                requests.get(
                    data_json["importantForeignTrendChart"][0]["imgUrl"]
                ).content
            )
        )
        img_file.show()
    elif indicator == "国外-日本新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(
                requests.get(
                    data_json["importantForeignTrendChart"][1]["imgUrl"]
                ).content
            )
        )
        img_file.show()
    elif indicator == "国外-意大利新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(
                requests.get(
                    data_json["importantForeignTrendChart"][2]["imgUrl"]
                ).content
            )
        )
        img_file.show()
    elif indicator == "国外-伊朗新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(
                requests.get(
                    data_json["importantForeignTrendChart"][3]["imgUrl"]
                ).content
            )
        )
        img_file.show()
    elif indicator == "国外-美国新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(
                requests.get(
                    data_json["importantForeignTrendChart"][4]["imgUrl"]
                ).content
            )
        )
        img_file.show()
    elif indicator == "国外-法国新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(
                requests.get(
                    data_json["importantForeignTrendChart"][5]["imgUrl"]
                ).content
            )
        )
        img_file.show()
    elif indicator == "国外-德国新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(
                requests.get(
                    data_json["importantForeignTrendChart"][6]["imgUrl"]
                ).content
            )
        )
        img_file.show()
    elif indicator == "国外-西班牙新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(
                requests.get(
                    data_json["importantForeignTrendChart"][7]["imgUrl"]
                ).content
            )
        )
        img_file.show()
    elif indicator == "国外-韩国新增确诊-趋势图":
        img_file = Image.open(
            BytesIO(
                requests.get(
                    data_json["importantForeignTrendChart"][8]["imgUrl"]
                ).content
            )
        )
        img_file.show()
    else:
        try:
            data_text = str(soup.find("script", attrs={"id": "getAreaStat"}))
            data_text_json = json.loads(
                data_text[data_text.find("= [{") + 2 : data_text.rfind("catch") - 1]
            )
            data_df = pd.DataFrame(data_text_json)
            sub_area = pd.DataFrame(
                data_df[data_df["provinceName"] == indicator]["cities"].values[0]
            )
            if sub_area.empty:
                return print("暂无分区域数据")
            sub_area.columns = ["区域", "现在确诊人数", "确诊人数", "疑似人数", "治愈人数", "死亡人数", "id"]
            sub_area = sub_area[["区域", "现在确诊人数", "确诊人数", "疑似人数", "治愈人数", "死亡人数"]]
            return sub_area
        except IndexError as e:
            print("请输入省/市的全称, 如: 浙江省/上海市 等")


def covid_baidu(indicator="湖北"):
    """
    百度-新型冠状病毒肺炎-疫情实时大数据报告
    https://voice.baidu.com/act/newpneumonia/newpneumonia/?from=osari_pc_1
    :param indicator: 看说明文档
    :type indicator: str
    :return: 指定 indicator 的数据
    :rtype: pandas.DataFrame
    """
    url = "https://huiyan.baidu.com/openapi/v1/migration/rank"
    payload = {
        "type": "move",
        "ak": "kgD2HiDnLdUhwzd3CLuG5AWNfX3fhLYe",
        "adminType": "country",
        "name": "全国",
    }
    r = requests.get(url, params=payload)
    move_in_df = pd.DataFrame(r.json()["result"]["moveInList"])
    move_out_df = pd.DataFrame(r.json()["result"]["moveOutList"])

    url = "https://opendata.baidu.com/api.php"
    payload = {
        "query": "全国",
        "resource_id": "39258",
        "tn": "wisetpl",
        "format": "json",
        "cb": "jsonp_1580470773343_11183",
    }
    r = requests.get(url, params=payload)
    text_data = r.text
    json_data_news = json.loads(
        text_data.strip("/**/jsonp_1580470773343_11183(").rstrip(");")
    )

    url = "https://opendata.baidu.com/data/inner"
    payload = {
        "tn": "reserved_all_res_tn",
        "dspName": "iphone",
        "from_sf": "1",
        "dsp": "iphone",
        "resource_id": "28565",
        "alr": "1",
        "query": "肺炎",
        "cb": "jsonp_1606895491198_93137",
    }
    r = requests.get(url, params=payload)
    json_data = json.loads(r.text[r.text.find("({") + 1 : r.text.rfind(");")])
    spot_report = pd.DataFrame(json_data["Result"][0]["DisplayData"]["result"]["items"])

    # domestic-city
    url = "https://voice.baidu.com/act/newpneumonia/newpneumonia/?from=osari_pc_1"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    data_json = demjson.decode(soup.find(attrs={"id": "captain-config"}).text)

    big_df = pd.DataFrame()
    for i, p in enumerate(
        jsonpath.jsonpath(data_json["component"][0]["caseList"], "$..area")
    ):
        temp_df = pd.DataFrame(
            jsonpath.jsonpath(data_json["component"][0]["caseList"], "$..subList")[i]
        )
        temp_df["province"] = p
        big_df = big_df.append(temp_df, ignore_index=True)
    domestic_city_df = big_df

    domestic_province_df = pd.DataFrame(data_json["component"][0]["caseList"]).iloc[
        :, :-2
    ]

    big_df = pd.DataFrame()
    for i, p in enumerate(
        jsonpath.jsonpath(data_json["component"][0]["caseOutsideList"], "$..area")
    ):
        temp_df = pd.DataFrame(
            jsonpath.jsonpath(
                data_json["component"][0]["caseOutsideList"], "$..subList"
            )[i]
        )
        temp_df["province"] = p
        big_df = big_df.append(temp_df, ignore_index=True)
    outside_city_df = big_df

    outside_country_df = pd.DataFrame(
        data_json["component"][0]["caseOutsideList"]
    ).iloc[:, :-1]

    big_df = pd.DataFrame()
    for i, p in enumerate(
        jsonpath.jsonpath(data_json["component"][0]["globalList"], "$..area")
    ):
        temp_df = pd.DataFrame(
            jsonpath.jsonpath(data_json["component"][0]["globalList"], "$..subList")[i]
        )
        temp_df["province"] = p
        big_df = big_df.append(temp_df, ignore_index=True)
    global_country_df = big_df

    global_continent_df = pd.DataFrame(data_json["component"][0]["globalList"])[
        ["area", "died", "crued", "confirmed", "confirmedRelative"]
    ]

    if indicator == "热门迁入地":
        return move_in_df
    elif indicator == "热门迁出地":
        return move_out_df
    elif indicator == "今日疫情热搜":
        return pd.DataFrame(json_data_news["data"][0]["list"][0]["item"])
    elif indicator == "防疫知识热搜":
        return pd.DataFrame(json_data_news["data"][0]["list"][1]["item"])
    elif indicator == "热搜谣言粉碎":
        return pd.DataFrame(json_data_news["data"][0]["list"][2]["item"])
    elif indicator == "复工复课热搜":
        return pd.DataFrame(json_data_news["data"][0]["list"][3]["item"])
    elif indicator == "热门人物榜":
        return pd.DataFrame(json_data_news["data"][0]["list"][4]["item"])
    elif indicator == "历史疫情热搜":
        return pd.DataFrame(json_data_news["data"][0]["list"][5]["item"])
    elif indicator == "搜索正能量榜":
        return pd.DataFrame(json_data_news["data"][0]["list"][6]["item"])
    elif indicator == "游戏榜":
        return pd.DataFrame(json_data_news["data"][0]["list"][7]["item"])
    elif indicator == "影视榜":
        return pd.DataFrame(json_data_news["data"][0]["list"][8]["item"])
    elif indicator == "小说榜":
        return pd.DataFrame(json_data_news["data"][0]["list"][9]["item"])
    elif indicator == "疫期飙升榜":
        return pd.DataFrame(json_data_news["data"][0]["list"][10]["item"])
    elif indicator == "实时播报":
        return spot_report
    elif indicator == "中国分省份详情":
        return domestic_province_df
    elif indicator == "中国分城市详情":
        return domestic_city_df
    elif indicator == "国外分国详情":
        return outside_country_df
    elif indicator == "国外分城市详情":
        return outside_city_df
    elif indicator == "全球分洲详情":
        return global_continent_df
    elif indicator == "全球分洲国家详情":
        return global_country_df


def covid_hist_city(city="武汉市"):
    """
    疫情历史数据 城市
    https://github.com/canghailan/Wuhan-2019-nCoV
    2019-12-01开始
    :return: 具体城市的疫情数据
    :rtype: pandas.DataFrame
    """
    url = "https://raw.githubusercontent.com/canghailan/Wuhan-2019-nCoV/master/Wuhan-2019-nCoV.json"
    r = requests.get(url)
    data_json = r.json()
    data_df = pd.DataFrame(data_json)
    return data_df[data_df["city"] == city]


def covid_hist_province(province="湖北省"):
    """
    疫情历史数据 省份
    https://github.com/canghailan/Wuhan-2019-nCoV
    2019-12-01开始
    :return: 具体省份的疫情数据
    :rtype: pandas.DataFrame
    """
    url = "https://raw.githubusercontent.com/canghailan/Wuhan-2019-nCoV/master/Wuhan-2019-nCoV.json"
    r = requests.get(url)
    data_json = r.json()
    data_df = pd.DataFrame(data_json)
    return data_df[data_df["province"] == province]


if __name__ == "__main__":
    # 历史数据
    # epidemic_hist_city_df = covid_hist_province()
    # print(epidemic_hist_city_df)
    # epidemic_hist_province_df = covid_hist_province(province="湖北省")
    # print(epidemic_hist_province_df)

    covid_dxy_df = covid_163()
    print(covid_dxy_df)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/4/1 12:59
# @Author  : justin.郑 3907721@qq.com
# @File    : star.py
# @Desc    : 星图
# https://star.toutiao.com/
import math
import time
import requests
import pandas as pd
from gopup.mcn import cons
from gopup.utils.utils import get_fields


def star_hot_list(section, hot_list, category, cookie):
    """
    星图热榜 抖音达人热榜
    :param section:
    :param hot_list:
    :param category:
    :param cookie:
    :return:
    """
    # cookie = cons.STAR_COOKIE
    headers = {
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.130 Safari/537.36",
        "referer": "https://star.toutiao.com/ad",
        "cookie": cookie
    }

    params = "%s-%s-%s" % (section, hot_list, category)
    try:
        url = cons.STAR_HOT_URL[params]
    except:
        return {"code": 401, "msg": "没有找到对应类型"}

    r = requests.get(url, headers=headers)

    publish_date = r.json()['data']['file_name'][-20:-1]
    data_all = r.json()['data']['stars']
    res_list = []
    new_rank = 1
    for data in data_all:
        res_dict = {
            "id": data['id'],
            "new_rank": new_rank,
            "nick_name": data['nick_name'],
            "avatar_uri": data['avatar_uri'],
            "province": data.setdefault('province'),
            "city": data['city'],
            "avg_play": data['avg_play'],
            "score": get_fields(data['fields'], "score"),
            "follower": get_fields(data['fields'], "follower"),
            "positive_vv": get_fields(data['fields'], "positive_vv"),
            "personal_interate_rate": get_fields(data['fields'], "personal_interate_rate"),
            "expected_cpm": get_fields(data['fields'], "expected_cpm"),
            "file_name": params,
            "publish_date": publish_date,
            "crawler_date": time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
        }
        res_list.append(res_dict)
        new_rank += 1
    df = pd.DataFrame(res_list)
    return df


def star_market_list(section="抖音达人", market_list="抖音传播任务", category="全部", limit=30, page=1, cookie=None):
    """
    达人广场 抖音达人
    :param section:
    :param market_list:
    :param category:
    :return:
    """
    cookie = cons.STAR_COOKIE
    res_url = get_star_market_url(category, cookie)

    headers = {
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.130 Safari/537.36",
        "referer": "https://star.toutiao.com/ad",
        "cookie": cookie
    }
    url = res_url % (limit, page)
    r = requests.get(url, headers=headers)
    try:
        res = r.json()['data']['authors']
    except:
        return {"msg": "cookie已经过期", "code": 401}
    return res


def get_star_market_url(category, cookie):
    limit = 10
    if category == "全部":
        url = "https://star.toutiao.com/v/api/demand/author_list/?limit=%s&need_detail=true&page=1&platform_source=1&task_category=1&order_by=score&use_recommend=1" % limit
        res_url = "https://star.toutiao.com/v/api/demand/author_list/?limit=%s&need_detail=true&page=%s&platform_source=1&task_category=1&order_by=score&use_recommend=1"
    else:
        category_list = cons.STAR_MARKET_DOUYIN_CATEGORY
        for cate in category_list:
            first_dict = cate['first']
            first_val = list(first_dict.values())[0]
            if category == first_val:
                tag = list(first_dict.keys())[0]
                url = "https://star.toutiao.com/v/api/demand/author_list/?limit=%s&need_detail=true&page=1&platform_source=1&task_category=1&tag=%s&order_by=score" % (
                limit, tag)
                res_url = "https://star.toutiao.com/v/api/demand/author_list/?limit=%s&need_detail=true&page=%s&platform_source=1&task_category=1&tag="+str(tag)+"&order_by=score"
            else:
                second_list = cate['second']
                for second_dict in second_list:
                    second_val = list(second_dict.values())[0]
                    if category == second_val:
                        tag = list(first_dict.keys())[0]
                        tag_level_two = list(second_dict.keys())[0]
                        url = "https://star.toutiao.com/v/api/demand/author_list/?limit=%s&need_detail=true&page=1&platform_source=1&task_category=1&tag=%s&tag_level_two=%s&order_by=score" % (limit, tag, tag_level_two)
                        res_url = "https://star.toutiao.com/v/api/demand/author_list/?limit=%s&need_detail=true&page=%s&platform_source=1&task_category=1&tag="+str(tag)+"&tag_level_two="+str(tag_level_two)+"&order_by=score"

    # headers = {
    #     "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.130 Safari/537.36",
    #     "referer": "https://star.toutiao.com/ad",
    #     "cookie": cookie
    # }
    #
    # r = requests.get(url, headers=headers)
    # total_count = r.json()['data']['pagination']['total_count']

    # return res_url, total_count
    return res_url


if __name__ == "__main__":
    # tmp = star_hot_list("抖音达人热榜", "星图指数榜", "财经投资")
    tmp = star_market_list(category="搞笑", limit=30, page=1)
    print(tmp)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/12/10 0010
# @Author  : justin.郑 3907721@qq.com
# @File    : charity.py
# @Desc    : 慈善中国

import pandas as pd
import requests
from tqdm import tqdm
from pyquery import PyQuery as pq


def _get_page_num_charity_organization():
    """
    慈善中国-慈善组织查询-总页数
    :return: 总页数
    """
    url = "http://cishan.chinanpo.gov.cn/biz/ma/csmh/a/csmhaDoSort.html"
    payload_params = {
        "aaee0102_03": "",
        "field": "aaex0131",
        "sort": "desc",
        "flag": "0",
    }
    payload_data = {"pageNo": "1"}
    r = requests.post(url, params=payload_params, data=payload_data)
    pages = r.text[r.text.find("第1页/共") + 5: r.text.rfind("页</font>")]
    return int(pages)


def charity_organization():
    """
    慈善中国-慈善组织查询
    http://cishan.chinanpo.gov.cn/biz/ma/csmh/a/csmhaindex.html
    :return: 慈善中国-慈善组织查询
    :rtype: pandas.DataFrame
    """
    page_num = _get_page_num_charity_organization()
    url = "http://cishan.chinanpo.gov.cn/biz/ma/csmh/a/csmhaDoSort.html"
    params = {
        "field": "aaex0131",
        "sort": "desc",
        "flag": "0",
    }
    outer_df = pd.DataFrame()
    for page in tqdm(range(1, page_num+1)):
        # page = 1
        params["pageNo"] = str(page)

        r = requests.post(url, params=params)
        inner_df = pd.read_html(r.text)[0]
        outer_df = outer_df.append(inner_df, ignore_index=True)
    return outer_df


if __name__ == "__main__":
    tmp = charity_organization()
    print(tmp)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/13 16:57
# @Author  : justin.郑 3907721@qq.com
# @File    : cons.py.py
# @Desc    : 新经济公司 配置文件

it_headers = {
    "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.88 Safari/537.36",
}
it_url = "https://jfds-1252952517.cos.ap-chengdu.myqcloud.com/akshare/data/data_juzi/juzi.csv"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/21 0021
# @Author  : justin.郑 3907721@qq.com
# @File    : index_baidu.py
# @Desc    : 获取百度指数

from gopup.index.baidu_decrypt import decrypt_func, get_encrypt_json, format_data, get_key, format_data_feed, format_data_new
import pandas as pd
import requests
import datetime
import json
import math


def decrypt(t: str, e: str) -> str:
    """
    解密函数
    :param t:
    :type t:
    :param e:
    :type e:
    :return:
    :rtype:
    """
    n, i, a, result = list(t), list(e), {}, []
    ln = int(len(n) / 2)
    start, end = n[ln:], n[:ln]
    a = dict(zip(end, start))
    return "".join([a[j] for j in e])


def get_ptbk(uniqid: str, cookie: str) -> str:
    headers = {
        "Accept": "application/json, text/plain, */*",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
        "Connection": "keep-alive",
        "Cookie": cookie,
        "Host": "index.baidu.com",
        "Referer": "http://index.baidu.com/v2/main/index.html",
        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.90 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    session = requests.Session()
    session.headers.update(headers)
    with session.get(
        url=f"http://index.baidu.com/Interface/ptbk?uniqid={uniqid}"
    ) as response:
        ptbk = response.json()["data"]
        return ptbk


def baidu_interest_index(word, cookie):
    """
    百度指数 人群画像兴趣分布
    :param word: 关键词
    :param cookie:
    :return:
        desc    兴趣分类
        tgi     TGI指数
        word_rate   关键词分布比率
        all_rate    全网分布比率
        period      周期范围
    """
    try:
        headers = {
            "Accept": "application/json, text/plain, */*",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9",
            "Cache-Control": "no-cache",
            "Cookie": cookie,
            "DNT": "1",
            "Host": "index.baidu.com",
            "Pragma": "no-cache",
            "Proxy-Connection": "keep-alive",
            "Referer": "zhishu.baidu.com",
            "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.90 Safari/537.36",
            "X-Requested-With": "XMLHttpRequest",
        }
        url = "http://index.baidu.com/api/SocialApi/interest?wordlist[]=%s" % word
        r = requests.get(url=url, headers=headers)
        data = json.loads(r.text)['data']
        period = "%s|%s" % (data['startDate'], data['endDate'])

        age_list = data['result'][0]['interest']
        age_df = pd.DataFrame(age_list)

        all_list = data['result'][1]['interest']
        all_df = pd.DataFrame(all_list)
        all_df.drop(["tgi", "typeId"], axis=1, inplace=True)

        res_df = pd.merge(age_df, all_df, on='desc')
        res_df['period'] = period
        res_df.drop(["typeId"], axis=1, inplace=True)
        res_df.rename(columns={'rate_x': 'word_rate', 'rate_y': 'all_rate'}, inplace=True)
        return res_df
    except:
        return None


def baidu_gender_index(word, cookie):
    """
    百度指数 人群画像性别分布
    :param word: 关键词
    :param cookie:
    :return:
        desc    性别
        tgi     TGI指数
        word_rate   关键词分布比率
        all_rate    全网分布比率
        period      周期范围
    """
    try:
        headers = {
            "Accept": "application/json, text/plain, */*",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9",
            "Cache-Control": "no-cache",
            "Cookie": cookie,
            "DNT": "1",
            "Host": "index.baidu.com",
            "Pragma": "no-cache",
            "Proxy-Connection": "keep-alive",
            "Referer": "zhishu.baidu.com",
            "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.90 Safari/537.36",
            "X-Requested-With": "XMLHttpRequest",
        }
        url = "http://index.baidu.com/api/SocialApi/baseAttributes?wordlist[]=%s" % word
        r = requests.get(url=url, headers=headers)
        data = json.loads(r.text)['data']
        period = "%s|%s" % (data['startDate'], data['endDate'])

        age_list = data['result'][0]['gender']
        age_df = pd.DataFrame(age_list)

        all_list = data['result'][1]['gender']
        all_df = pd.DataFrame(all_list)
        all_df.drop(["tgi", "typeId"], axis=1, inplace=True)

        res_df = pd.merge(age_df, all_df, on='desc')
        res_df['period'] = period
        res_df.drop(["typeId"], axis=1, inplace=True)
        res_df.rename(columns={'rate_x': 'word_rate', 'rate_y': 'all_rate'}, inplace=True)
        return res_df
    except:
        return None


def baidu_age_index(word, cookie):
    """
    百度指数 人群画像年龄分布
    :param word: 关键词
    :param cookie:
    :return:
        desc    年龄范围
        tgi     TGI指数
        word_rate   关键词分布比率
        all_rate    全网分布比率
        period      周期范围
    """
    try:
        headers = {
            "Accept": "application/json, text/plain, */*",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9",
            "Cache-Control": "no-cache",
            "Cookie": cookie,
            "DNT": "1",
            "Host": "index.baidu.com",
            "Pragma": "no-cache",
            "Proxy-Connection": "keep-alive",
            "Referer": "zhishu.baidu.com",
            "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.90 Safari/537.36",
            "X-Requested-With": "XMLHttpRequest",
        }
        url = "http://index.baidu.com/api/SocialApi/baseAttributes?wordlist[]=%s" % word
        r = requests.get(url=url, headers=headers)
        data = json.loads(r.text)['data']
        period = "%s|%s" % (data['startDate'], data['endDate'])

        age_list = data['result'][0]['age']
        age_df = pd.DataFrame(age_list)

        all_list = data['result'][1]['age']
        all_df = pd.DataFrame(all_list)
        all_df.drop(["tgi", "typeId"], axis=1, inplace=True)

        res_df = pd.merge(age_df, all_df, on='desc')
        res_df['period'] = period
        res_df.drop(["typeId"], axis=1, inplace=True)
        res_df.rename(columns={'rate_x': 'word_rate', 'rate_y': 'all_rate'}, inplace=True)
        return res_df
    except:
        return None


def baidu_atlas_index(word, cookie, date=None):
    """
    百度指数 需求图谱
    :param word: 关键词
    :param cookie:
    :param date: 周期
    :return:
        period  周期范围
        word    相关词
        pv      搜索热度
        ratio   搜索变化率
    """

    try:
        headers = {
            "Accept": "application/json, text/plain, */*",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9",
            "Cache-Control": "no-cache",
            "Cookie": cookie,
            "DNT": "1",
            "Host": "index.baidu.com",
            "Pragma": "no-cache",
            "Proxy-Connection": "keep-alive",
            "Referer": "zhishu.baidu.com",
            "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.90 Safari/537.36",
            "X-Requested-With": "XMLHttpRequest",
        }
        if date == None:
            date = ""
        url = "http://index.baidu.com/api/WordGraph/multi?wordlist[]=%s&datelist=%s" % (word, date)
        r = requests.get(url=url, headers=headers)
        data = json.loads(r.text)['data']
        wordlist = data['wordlist'][0]['wordGraph']
        res_list = []
        for word in wordlist:
            tmp = {
                "word": word['word'],
                "pv": word['pv'],
                "ratio": word['ratio'],
                "period": data['period'],
                "sim": word['sim']
            }
            res_list.append(tmp)
        df = pd.DataFrame(res_list)
        return df
    except:
        return None


def baidu_search_index(word, start_date, end_date, cookie, type="all"):
    # 百度搜索数据
    try:
        keywords_list = [[word]]
        encrypt_json = get_encrypt_json(
            start_date=start_date,
            end_date=end_date,
            keywords=keywords_list,
            type='search',
            area=0,
            cookies=cookie
        )

        encrypt_datas = encrypt_json['data']['userIndexes']
        uniqid = encrypt_json['data']['uniqid']

        result = []
        key = get_key(uniqid, cookie)
        for encrypt_data in encrypt_datas:
            encrypt_data[type]['data'] = decrypt_func(key, encrypt_data[type]['data'])

            for formated_data in format_data(encrypt_data, kind=type):
                result.append(formated_data)
                # yield formated_data

        data_df = pd.DataFrame(result)
        data_df.index = pd.to_datetime(data_df["date"])
        del data_df["date"]
        return data_df
    except Exception as e:
        return None


def baidu_info_index(word, start_date, end_date, cookie):
    # 百度资讯指数
    try:
        keywords_list = [[word]]
        encrypt_json = get_encrypt_json(
            start_date=start_date,
            end_date=end_date,
            keywords=keywords_list,
            type='feed',
            area=0,
            cookies=cookie
        )

        encrypt_datas = encrypt_json['data']['index']
        uniqid = encrypt_json['data']['uniqid']

        result = []
        key = get_key(uniqid, cookie)
        for encrypt_data in encrypt_datas:
            encrypt_data['data'] = decrypt_func(key, encrypt_data['data'])

            for formated_data in format_data_feed(encrypt_data):
                result.append(formated_data)
                # yield formated_data

        data_df = pd.DataFrame(result)
        data_df.index = pd.to_datetime(data_df["date"])
        del data_df["date"]
        return data_df
    except Exception as e:
        return None


def baidu_media_index(word, start_date, end_date, cookie):
    # 百度媒体指数
    try:
        keywords_list = [[word]]
        encrypt_json = get_encrypt_json(
            start_date=start_date,
            end_date=end_date,
            keywords=keywords_list,
            type='news',
            area=0,
            cookies=cookie
        )

        encrypt_datas = encrypt_json['data']['index']
        uniqid = encrypt_json['data']['uniqid']

        result = []
        key = get_key(uniqid, cookie)
        for encrypt_data in encrypt_datas:
            encrypt_data['data'] = decrypt_func(key, encrypt_data['data'])

            for formated_data in format_data_new(encrypt_data):
                result.append(formated_data)
                # yield formated_data

        data_df = pd.DataFrame(result)
        data_df.index = pd.to_datetime(data_df["date"])
        del data_df["date"]
        return data_df
    except Exception as e:
        return None


if __name__ == "__main__":
    cookie = '''BIDUPSID=512FE19892358D21D38C8FC50F5F37F7; PSTM=1660901365; BAIDUID=53AD0CE37FCDB36D9D1B39A93FE374F4:SL=0:NR=10:FG=1; Hm_up_d101ea4d2a5c67dab98251f0b5de24dc=%7B%22uid_%22%3A%7B%22value%22%3A%22334753876%22%2C%22scope%22%3A1%7D%7D; BDUSS=ZvNlM1RndBRDQ3bko0S0tEOWktVE02Tnd4b0R0dVZ1fmIwLWpPdjNDOWZ4a2RqSVFBQUFBJCQAAAAAAAAAAAEAAABU8PMTst24-dauw~cAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAF85IGNfOSBjfk; MCITY=-%3A; BDORZ=B490B5EBF6F3CD402E515D22BCDA1598; BDSFRCVID_BFESS=G_4OJexroG06EXRj-uKarZxkLdsdTYQTDYLEOwXPsp3LGJLVgmxZEG0PtEw4Pz0bwaLOogKKLgOTHULF_2uxOjjg8UtVJeC6EG0Ptf8g0M5; H_BDCLCKID_SF_BFESS=tb4J_KKytC-3H48k-4QEbbQH-UnLqMbdJgOZ04n-ah02Ml5y04CV5fP_KR6OaM7b-Knnhxjm3UTdsq76Wh35K5tTQP6rLtbLMNQ4KKJxbp5bMMJuD-5b-fAghUJiBM7MBan7-lRIXKohJh7FM4tW3J0ZyxomtfQxtNRJ0DnjtpChbRO4-TFKej3yjM5; BA_HECTOR=81a0ak852k2104a40k04aafq1hj5n2m18; ZFY=utya:BRNupJGq9supvasQbProo6s1q6EhqW:BvXv2orTE:C; BAIDUID_BFESS=53AD0CE37FCDB36D9D1B39A93FE374F4:SL=0:NR=10:FG=1; bdindexid=sftj5d8kfth69n1mqobrdpjmb6; Hm_lvt_d101ea4d2a5c67dab98251f0b5de24dc=1663127080,1664326055,1664326075; SIGNIN_UC=70a2711cf1d3d9b1a82d2f87d633bd8a04143385244YiyThQ5ysTqMgVj%2Fn6xC2SYZF0VE07SocZWWdU6ZnBkjQZwGAwJERGknT7CvfJjH9eFfgmYY53HOhSpOWKvK53E55xQOv5kXD1bACugrYHz26O8qmDIhSU7Tx2yGlQejq95SvYoXlAIBBDD0W0D1x4Bg4KlteVdTV7ShFG4iemhL3681G%2FEmDO8yTdxSgo7BEQKCTCoE9rr8HMGgon8hx8nJb3d4h%2FV1KYbRpLZ7J8nSjcEdPAXTt5R9QjpnNyWo89ncXTlKDH452%2BAAjYjf8DBbhTymoZo5%2FiwHxEdy8jkGAZC%2FYhHSHQureM%2B1FQwIKBaJtigI9ufAXWXqzaOWew%3D%3D22115626617237125877026469513709; __cas__rn__=414338524; __cas__st__212=12ef083e20021e38c1842b8cda8fca11a37493f871085428583d68fe518bc4dd44337f5cd54479ecf78c4360; __cas__id__212=42043514; CPID_212=42043514; CPTK_212=1578600173; RT="z=1&dm=baidu.com&si=136a97b7-5316-4e2d-87b0-ed0c2e7d1165&ss=l8kwre9b&sl=m&tt=tr2&bcn=https%3A%2F%2Ffclog.baidu.com%2Flog%2Fweirwood%3Ftype%3Dperf"; Hm_lpvt_d101ea4d2a5c67dab98251f0b5de24dc=1664326877; ab_sr=1.0.1_ZGE0OTEyZDJjODRhOTUwMWJkMjgyZWExMTY1ODJiNjlmODg5OTQ5MWMzYzcyODhhZDYyZTE5N2ZkYWMyYjIzNjcyZjMyYjMxNTZiMTkwMDk5YjE3OTZmMDg2NDkxNTgxMDNiYjI0YzY5YjM4OTlmYjU5OWUzNDgyZTAzNTc0MzFlZDRhYjY2ZjAyNzhjYjg3ZTg4Nzc3YzdmYTY2NDYyNw==; BDUSS_BFESS=ZvNlM1RndBRDQ3bko0S0tEOWktVE02Tnd4b0R0dVZ1fmIwLWpPdjNDOWZ4a2RqSVFBQUFBJCQAAAAAAAAAAAEAAABU8PMTst24-dauw~cAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAF85IGNfOSBjfk'''
    data = baidu_media_index(word="极限挑战", start_date='2022-09-01', end_date='2022-09-19', cookie=cookie)
    # data = baidu_atlas_index(word="极限挑战", cookie=cookie)
    print(data)






#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/4/16 11:27
# @Author  : justin.郑 3907721@qq.com
# @File    : utils.py
# @Desc    :


def get_fields(fields, label):
    """ 搜索DICT中的label 获取值"""
    for res_dict in fields:
        if res_dict['label'] == label:
            return res_dict['value']
    return ""




#!/usr/bin/env python
# _*_ coding: utf-8 _*_
# @Time : 2022/9/28 11:03
# @Author : justin.郑 3907721@qq.com
# @File : errors.py
# @desc :

from enum import Enum


class ErrorCode(int, Enum):
    UNKNOWN = 10002
    NETWORK_ERROR = 10003

    # 百度指数
    NO_LOGIN = 20000
    KEYWORD_LIMITED = 20001
    REQUEST_LIMITED = 20002
    CHECK_KEYWORD_LIMITED = 20003

    # 百度的登录
    GET_QR_FAIL = 20010
    LOGIN_FAIL = 20011
    INDEX_LOGIN_FAIL = 20012

    # 天眼查
    TYC_COMPANY_COUNT_FAIL = 20020


CODE_MSG_MAP = {
    ErrorCode.NO_LOGIN: 'cookies失效，请重新获取cookies',
    ErrorCode.UNKNOWN: '未知错误',
    ErrorCode.NETWORK_ERROR: '网络错误',
    ErrorCode.KEYWORD_LIMITED: ('关键词最多传递5个, '
                                '可以使用`from qdata.baidu_index.common import split_keywords`,'
                                '对关键词进行切分'),
    ErrorCode.REQUEST_LIMITED: "该账号请求过于频繁, 请降低请求频率",
    ErrorCode.CHECK_KEYWORD_LIMITED: "最多传入15个关键词",
    ErrorCode.GET_QR_FAIL: "获取二维码失败",
    ErrorCode.LOGIN_FAIL: "百度登录失败",
    ErrorCode.INDEX_LOGIN_FAIL: "百度指数登录失败",
    ErrorCode.TYC_COMPANY_COUNT_FAIL: "获取天眼查公司数量失败"
}


class GopupError(Exception):
    def __init__(self, code: ErrorCode, info: str = ""):
        self.code = code
        self.msg = CODE_MSG_MAP.get(code) + (info and f", {info}")

    def __str__(self):
        return repr(f"ERROR-{self.code}: {self.msg}")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/4/1 13:09
# @Author  : justin.郑 3907721@qq.com
# @File    : cons.py
# @Desc    : 网红经济行业

STAR_COOKIE = 'gr_user_id=d73ea970-adf9-44f1-ba2f-2b1e49b6d1e7; grwng_uid=ba191569-5bb2-4fe2-b810-bc9e601d05d4; tt_webid=6807980764321318408; csrftoken=oX0pXOTFAOWZzT9F6YiTXl9IaUQRqFzk; odin_tt=8da95c0df1c8b0895664d60f7a0364faae5f7976d37a3ecd8b9c0c0ccaae9fdaa482facc4cc18141b88637b65f1cb5606993458b12f9ebc871e7ca4075c2757c; uid_tt_ss=3c813e052e5e95791768bd4231001b83; sessionid_ss=fc6684106be289e3779f9f42642b6d1d; gftoken=ZmM2Njg0MTA2YnwxNTg1NzA0MzYzNTd8fDAGBgYGBgY; _ga=GA1.2.1344526501.1586990335; 8632e941eb705978_gr_session_id=302d6c66-4b48-46c1-83a4-af955647e153; 8632e941eb705978_gr_session_id_302d6c66-4b48-46c1-83a4-af955647e153=true; s_v_web_id=k99e1ezn_l6N3CQ5r_EWzv_4Mw1_9KWY_F9ONZ8zZJCVC; login_flag=ac43e4155b6a263e3331a583d086d780; sid_tt=5b218149652bc0cc7b4f7e56f2d908a9; uid_tt=f3105a05f7e173962fde7c8e7f647d26fde210733ea4c266a870ee459c772584; sessionid=5b218149652bc0cc7b4f7e56f2d908a9; star_sessionid=5b218149652bc0cc7b4f7e56f2d908a9; sid_guard="5b218149652bc0cc7b4f7e56f2d908a9|1587442099|15552000|Sun\054 18-Oct-2020 04:08:19 GMT"; SLARDAR_WEB_ID=31ed1b8f-dd60-4d2e-ab09-e952113fee1a'


STAR_HOT_URL = {
    "抖音达人热榜-星图指数榜-全部": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=2fed15d4bd4ced9f29081b6636529be3",
    "抖音达人热榜-星图指数榜-颜值达人": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E9%A2%9C%E5%80%BC%E8%BE%BE%E4%BA%BA&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=dd13e4123f98b324a180bab753bc628c",
    "抖音达人热榜-星图指数榜-剧情搞笑": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E5%89%A7%E6%83%85%E6%90%9E%E7%AC%91&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=ad12718bce3776998bb250bc4cd3a6a9",
    "抖音达人热榜-星图指数榜-美妆": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E7%BE%8E%E5%A6%86&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=ff2e737d9008f495347908924878aaaf",
    "抖音达人热榜-星图指数榜-时尚": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E6%97%B6%E5%B0%9A&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=6f4ba341c3744daabf0456d482d11dc9",
    "抖音达人热榜-星图指数榜-萌宠": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E8%90%8C%E5%AE%A0&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=e42e33dbff38f86e086a92d4a7c701ad",
    "抖音达人热榜-星图指数榜-音乐": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E9%9F%B3%E4%B9%90&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=458e07ea4f387008dc21a4a4321ece76",
    "抖音达人热榜-星图指数榜-舞蹈": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E8%88%9E%E8%B9%88&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=58df0a68bbc790f1f7a72cb366ef774f",
    "抖音达人热榜-星图指数榜-美食": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E7%BE%8E%E9%A3%9F&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=109060a3de7154dfeeb7bbb3d71c815a",
    "抖音达人热榜-星图指数榜-游戏": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E6%B8%B8%E6%88%8F&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=3c0bbcb5a77af35e89d5a3f4c1f27d6e",
    "抖音达人热榜-星图指数榜-旅行": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E6%97%85%E8%A1%8C&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=8ad4e0f8d311331679df0ee4ee0e2222",
    "抖音达人热榜-星图指数榜-汽车": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E6%B1%BD%E8%BD%A6&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=576874d80792429288226e1eeb3d8fe3",
    "抖音达人热榜-星图指数榜-生活": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E7%94%9F%E6%B4%BB&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=f4afdc41eff79a011c15240aafe699ad",
    "抖音达人热榜-星图指数榜-测评": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E6%B5%8B%E8%AF%84&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=13d3b98b4ed53cd4bd94b484f05f6fb8",
    "抖音达人热榜-星图指数榜-二次元": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E4%BA%8C%E6%AC%A1%E5%85%83&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=94f85ba5e09faa8f44e73281add376dd",
    "抖音达人热榜-星图指数榜-母婴亲子": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E6%AF%8D%E5%A9%B4%E4%BA%B2%E5%AD%90&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=bbfe3df3e4723905aa1ce85f8d517d92",
    "抖音达人热榜-星图指数榜-科技数码": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E7%A7%91%E6%8A%80%E6%95%B0%E7%A0%81&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=2c5f2fd675f1a2c6b4489753fc19f417",
    "抖音达人热榜-星图指数榜-教育培训": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E6%95%99%E8%82%B2%E5%9F%B9%E8%AE%AD&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=209545266b0ab86277602f6bf366bffa",
    "抖音达人热榜-星图指数榜-运动健身": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E8%BF%90%E5%8A%A8%E5%81%A5%E8%BA%AB&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=83aed6604a6bd57b8b24b0315e02669a",
    "抖音达人热榜-星图指数榜-家居家装": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E5%AE%B6%E5%B1%85%E5%AE%B6%E8%A3%85&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=253a39d7354fdfeda434b71f521db36c",
    "抖音达人热榜-星图指数榜-才艺技能": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E6%89%8D%E8%89%BA%E6%8A%80%E8%83%BD&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=2b2635b3697700078a79c716cb019d61",
    "抖音达人热榜-星图指数榜-影视娱乐": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E5%BD%B1%E8%A7%86%E5%A8%B1%E4%B9%90&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=d2b2e189aec4c6349ad2980d0279da6e",
    "抖音达人热榜-星图指数榜-艺术文化": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E8%89%BA%E6%9C%AF%E6%96%87%E5%8C%96&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=4b1191492b150415e331da02c69c0b10",
    "抖音达人热榜-星图指数榜-财经投资": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E8%B4%A2%E7%BB%8F%E6%8A%95%E8%B5%84&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=313239b33b29720e752698033d72e0ce",
    "抖音达人热榜-星图指数榜-情感": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E6%83%85%E6%84%9F&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=be47713df317e09574b0a7e880e3cec2",
    "抖音达人热榜-星图指数榜-三农": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E4%B8%89%E5%86%9C&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=23c34c6b6a480c5a292e76eced7b5252",
    "抖音达人热榜-星图指数榜-园艺": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6766936376500813837&tag=%E5%9B%AD%E8%89%BA&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=929bfc99bbfd53c671e7538a5d0e3951",

    "抖音达人热榜-种草指数榜-全部": "https://star.toutiao.com/h/api/gateway/handler_get/?hot_list_id=6758055829141717005&tag=&service_name=author.AdStarAuthorService&service_method=GetHotListData&sign=e4476e7c0d875d205f6b36b8d3bc2da0",

}

STAR_MARKET_DOUYIN_CATEGORY = [
    {
		"second": [{
				73: "美女"
			},
			{
				74: "帅哥"
			}
		],
		"first": {
			72: "颜值达人"
		}
	},
	{
		"second": [{
				98: "剧情"
			},
			{
				99: "搞笑"
			}
		],
		"first": {
			97: "剧情搞笑"
		}
	},
	{
		"second": [{
				2: "美妆教程"
			},
			{
				3: "妆容展示"
			},
			{
				4: "护肤保养"
			},
			{
				5: "美妆测评种草"
			}
		],
		"first": {
			1: "美妆"
		}
	},
	{
		"second": [{
				7: "穿搭"
			},
			{
				8: "街拍"
			},
			{
				10: "造型"
			}
		],
		"first": {
			6: "时尚"
		}
	},
	{
		"second": [{
				12: "日常宠物"
			},
			{
				13: "特别宠物"
			},
			{
				14: "宠物周边"
			}
		],
		"first": {
			11: "萌宠"
		}
	},
	{
		"second": [{
				42: "歌曲演唱"
			},
			{
				43: "乐器演奏"
			},
			{
				44: "音乐教学"
			},
			{
				45: "音乐其他"
			}
		],
		"first": {
			41: "音乐"
		}
	},
	{
		"second": [],
		"first": {
			46: "舞蹈"
		}
	},
	{
		"second": [{
				49: "美食教程"
			},
			{
				50: "美食探店"
			},
			{
				51: "吃播大胃王"
			},
			{
				52: "美食产品测评"
			},
			{
				53: "乡村野食"
			},
			{
				54: "美食其他"
			}
		],
		"first": {
			48: "美食"
		}
	},
	{
		"second": [{
				119: "真人出镜"
			},
			{
				120: "游戏实况"
			},
			{
				121: "游戏剧情"
			},
			{
				122: "游戏解说"
			},
			{
				123: "游戏资讯"
			}
		],
		"first": {
			23: "游戏"
		}
	},
	{
		"second": [{
				28: "旅行记录"
			},
			{
				29: "旅行攻略"
			},
			{
				30: "旅行推荐"
			}
		],
		"first": {
			27: "旅行"
		}
	},
	{
		"second": [{
				32: "汽车测评"
			},
			{
				33: "汽车知识"
			},
			{
				34: "汽车周边"
			}
		],
		"first": {
			31: "汽车"
		}
	},
	{
		"second": [{
				39: "生活小窍门"
			},
			{
				40: "好物推荐"
			},
			{
				118: "健康养生"
			}
		],
		"first": {
			36: "生活"
		}
	},
	{
		"second": [{
				16: "美妆测评"
			},
			{
				17: "3C数码测评"
			},
			{
				18: "汽车测评"
			},
			{
				19: "美食产品测评"
			},
			{
				20: "母婴产品测评"
			},
			{
				21: "综合测评"
			}
		],
		"first": {
			15: "测评"
		}
	},
	{
		"second": [{
				125: "二次元真人"
			},
			{
				126: "动画漫画"
			},
			{
				127: "配音声优"
			},
			{
				128: "宅物手办"
			}
		],
		"first": {
			25: "二次元"
		}
	},
	{
		"second": [{
				56: "育儿科普"
			},
			{
				57: "萌娃日常"
			},
			{
				58: "亲子互动"
			},
			{
				59: "测评种草"
			}
		],
		"first": {
			55: "母婴亲子"
		}
	},
	{
		"second": [{
				65: "3C数码"
			},
			{
				66: "家居电器"
			}
		],
		"first": {
			64: "科技数码"
		}
	},
	{
		"second": [{
				69: "考学培训"
			},
			{
				70: "语言教学"
			},
			{
				71: "个人管理"
			}
		],
		"first": {
			68: "教育培训"
		}
	},
	{
		"second": [{
				61: "健身"
			},
			{
				62: "竞技体育"
			},
			{
				63: "极限运动"
			}
		],
		"first": {
			60: "运动健身"
		}
	},
	{
		"second": [{
				76: "家装设计"
			},
			{
				77: "装修知识"
			}
		],
		"first": {
			75: "家居家装"
		}
	},
	{
		"second": [{
				80: "创意才能"
			},
			{
				81: "手工"
			},
			{
				82: "摄影"
			},
			{
				83: "绘画"
			},
			{
				84: "其他才艺"
			}
		],
		"first": {
			79: "才艺技能"
		}
	},
	{
		"second": [],
		"first": {
			85: "影视娱乐"
		}
	},
	{
		"second": [{
				88: "传统文化"
			},
			{
				89: "人文科普"
			},
			{
				90: "自然科学"
			}
		],
		"first": {
			87: "艺术文化"
		}
	},
	{
		"second": [{
				92: "传统金融"
			},
			{
				93: "互联网金融"
			},
			{
				94: "财经知识"
			}
		],
		"first": {
			91: "财经投资"
		}
	},
	{
		"second": [],
		"first": {
			100: "情感"
		}
	},
	{
		"second": [],
		"first": {
			95: "三农"
		}
	},
	{
		"second": [],
		"first": {
			102: "园艺"
		}
	}
]


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/2/19 0019
# @Author  : justin.郑 3907721@qq.com
# @File    : index_sogou.py
# @Desc    : 搜狗指数

import json
import pandas as pd
import requests
from gopup.index.cons import index_toutiao_headers


def sogou_index(keyword, start_date, end_date, data_type="SEARCH_ALL"):
    """
    搜狗指数趋势数据
    :param keyword:     关键词
    :param start_date:  开始日期
    :param end_date:    截止日期
    :param data_type:   指数趋势
    :return:
        datetime    日期
        index       指数
    """

    # SEARCH_ALL 整体趋势  SEARCH_PC PC趋势  SEARCH_WAP 移动趋势
    try:
        url = "http://zhishu.sogou.com/getDateData?kwdNamesStr=%s&startDate=%s&endDate=%s&dataType=%s&queryType=INPUT" % (keyword, start_date, end_date, data_type)

        res = requests.get(url, headers=index_toutiao_headers)
        pv_list = json.loads(res.text)['data']['pvList'][0]
        df = pd.DataFrame(pv_list)
        df['index'] = df['pv']
        df = df.drop(['kwdId', 'isPeak', 'id', 'pv'], axis=1)
        return df
    except:
        return None


if __name__ == "__main__":
    sogou_index(keyword="耐克", start_date="20210101", end_date="20210218")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/11/14 21:38
# @Author  : justin.郑 3907721@qq.com
# @File    : fund.py
# @Desc    : 基金数据

import json
import pandas as pd
import requests


def fund_etf_category_sina(symbol="封闭式基金"):
    """
    基金列表
    http://vip.stock.finance.sina.com.cn/fund_center/index.html#jjhqetf
    :param symbol: choice of {"封闭式基金", "ETF基金", "LOF基金"}
    :type symbol: str
    :return: 指定 symbol 的基金列表
    :rtype: pandas.DataFrame
    """
    fund_map = {
        "封闭式基金": "close_fund",
        "ETF基金": "etf_hq_fund",
        "LOF基金": "lof_hq_fund",
    }
    url = "http://vip.stock.finance.sina.com.cn/quotes_service/api/jsonp.php/IO.XSRV2.CallbackList['da_yPT46_Ll7K6WD']/Market_Center.getHQNodeDataSimple"
    params = {
        "page": "1",
        "num": "1000",
        "sort": "symbol",
        "asc": "0",
        "node": fund_map[symbol],
        "[object HTMLDivElement]": "qvvne",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = json.loads(data_text[data_text.find("([")+1:-2])
    temp_df = pd.DataFrame(data_json)
    res_df = temp_df[["symbol", "name"]]
    return res_df


def fund_etf_hist_sina(symbol="sz159996"):
    """
    ETF 基金的日行情数据
    http://finance.sina.com.cn/fund/quotes/159996/bc.shtml
    :param symbol: 基金名称, 可以通过 fund_etf_category_sina 函数获取
    :type symbol: str
    :return: ETF 基金的日行情数据
    :rtype: pandas.DataFrame
    """
    url = f"https://finance.sina.com.cn/realstock/company/{symbol}/hisdata/klc_kl.js"
    r = requests.get(url)
    js_code = py_mini_racer.MiniRacer()
    js_code.eval(hk_js_decode)
    dict_list = js_code.call('d', r.text.split("=")[1].split(";")[0].replace('"', ""))  # 执行js解密代码
    temp_df = pd.DataFrame(dict_list)
    temp_df["date"] = pd.to_datetime(temp_df["date"]).dt.date
    return temp_df


if __name__ == '__main__':
    fund_etf_category_sina_df = fund_etf_category_sina(symbol="ETF基金")
    print(fund_etf_category_sina_df)

    # fund_etf_hist_sina_df = fund_etf_hist_sina(symbol="sz169103")
    # print(fund_etf_hist_sina_df)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/2/5 0005
# @Author  : justin.郑 3907721@qq.com
# @File    : train.py
# @Desc    : 12306车站、车次数据

import pandas as pd
import requests
from pyquery import PyQuery as pq


def station_name():
    """
    获取12306车站信息
    Returns
    -------
    DataFrame
        "拼音码、站名、电报码、拼音、首字母、ID""
    """
    try:
        url = "https://kyfw.12306.cn/otn/resources/js/framework/station_name.js"
        r = requests.get(url=url)
        data_text = r.text
        tmp_str = data_text[data_text.find("='")+3: -2]
        tmp_list = tmp_str.split('@')
        res_list = []
        for li in tmp_list:
            res_list.append(li.split('|'))
        columns = ["拼音码", "站名", "电报码", "拼音", "首字母", "ID"]
        data_df = pd.DataFrame(res_list, columns=columns)
        data_df.set_index("ID", inplace=True)
        return data_df
    except:
        return None


# def train_list():
#     """
#     获取12306车次信息
#     Returns
#     -------
#     DataFrame
#         "拼音码、站名、电报码、拼音、首字母、ID""
#     """
#     url = "https://kyfw.12306.cn/otn/resources/js/query/train_list.js"
#     r = requests.get(url=url)
#     data_text = r.text
#     tmp_str = data_text[data_text.find("={")+1:]
#     # tmp_dict = json.loads(tmp_str)['2019-07-16']
#     tmp_list = tmp_str.split('@')
#     res_list = []
#     for li in tmp_list:
#         res_list.append(li.split('|'))
#     columns = ["拼音码", "站名", "电报码", "拼音", "首字母", "ID"]
#     data_df = pd.DataFrame(res_list, columns=columns)
#     data_df.set_index("ID", inplace=True)
#     return data_df


def train_time_table(train_number):
    """
    车次时刻表
    :return:
        DataFrame
        "车次、车型、始发站、终点站、始发时、终到时、全程时间"
    """
    try:
        url = "https://www.keyunzhan.com/dongche/%s/" % train_number
        r = requests.get(url=url)
        doc = pq(r.text)
        tds = doc(".listTable td[bgcolor='#FFFFFF']")
        tmp = []
        for v in tds.items():
            tmp.append(v.text())
        res = {
            "车次": tmp[0],
            "车型": tmp[1],
            "始发站": tmp[2],
            "终点站": tmp[3],
            "始发时": tmp[4],
            "终到时": tmp[5],
            "全程时间": tmp[6]
        }
        data_df = pd.DataFrame(res, index=[0])
        return data_df
    except:
        return None


if __name__ == '__main__':
    tmp = train_time_table(train_number="t15")
    print(tmp)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/13 16:58
# @Author  : justin.郑 3907721@qq.com
# @File    : itjuzi.py
# @Desc    : IT桔子

import pandas as pd
import requests
from gopup.fortune.cons import it_url, it_headers
import ssl
ssl._create_default_https_context = ssl._create_unverified_context


def death_company():
    """
    倒闭公司
    https://www.itjuzi.com/deathCompany
    :return: pandas.DataFrame
    """
    try:
        temp_df = pd.read_csv(it_url, index_col=0)
        for i in range(1, 3):
            json_url = (
                f"https://www.itjuzi.com/api/closure?com_prov=&fund_status=&sort=&page={i}"
            )
            data_json = requests.get(url=json_url, headers=it_headers).json()
            data_df = data_json["data"]["info"]
            data_df = pd.DataFrame(data_df)
            data_df = data_df[
                [
                    "com_name",
                    "born",
                    "com_change_close_date",
                    "live_time",
                    "total_money",
                    "cat_name",
                    "com_prov",
                ]
            ]
            temp_df = temp_df.append(data_df, ignore_index=True)
            temp_df.drop_duplicates(inplace=True)
        return temp_df
    except:
        return None


def nicorn_company():
    """
    独角兽公司
    :return: pandas.DataFrame
    """
    try:
        temp_df = pd.read_csv(
            "https://jfds-1252952517.cos.ap-chengdu.myqcloud.com/akshare/data/data_juzi/nicorn_company.csv",
            index_col=0,
        )
        for i in range(1, 2):
            json_url = f"https://www.itjuzi.com/api/nicorn?page={i}&com_prov=&cat_id=&order_id=1&com_name="
            data_json = requests.get(url=json_url, headers=it_headers).json()
            data_df = data_json["data"]["data"]
            data_df = pd.DataFrame(data_df)
            temp_df = temp_df.append(data_df, ignore_index=True)
            temp_df.drop_duplicates(inplace=True)
        return temp_df
    except:
        return None


def maxima_company():
    """
    千里马公司
    :return: pandas.DataFrame
    """
    try:
        temp_df = pd.read_csv(
            "https://jfds-1252952517.cos.ap-chengdu.myqcloud.com/akshare/data/data_juzi/maxima.csv",
            index_col=0,
        )
        temp_df.head().append(temp_df.tail())
        for i in range(1, 2):
            json_url = f"https://www.itjuzi.com/api/maxima/?page={i}&com_prov=&cat_id=&order_id=1&com_name="
            data_json = requests.get(url=json_url, headers=it_headers).json()
            data_df = data_json["data"]["data"]
            data_df = pd.DataFrame(data_df)
            temp_df = temp_df.append(data_df, ignore_index=True)
            temp_df.drop_duplicates(inplace=True)
        return temp_df
    except:
        return None


if __name__ == "__main__":
    death_company_df = death_company()
    print(death_company_df)
    nicorn_company_df = nicorn_company()
    print(nicorn_company_df)
    maxima_company_df = maxima_company()
    print(maxima_company_df)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/17 19:42
# @Author  : justin.郑 3907721@qq.com
# @File    : client.py
# @Desc    : 专业版 数据接口

import pandas as pd
import json
from functools import partial
import requests


class DataApi:
    def __init__(self, token, timeout=15):
        """
        API接口TOKEN，用于用户认证
        :param token:
        :param timeout:
        """
        self._token = token
        self._timeout = timeout
        self._http_url = 'http://www.gopup.cn/api/v1'

    def query(self, api_name, fields=None, **kwargs):
        """
        # api_name，接口名称；
        # token，用于识别唯一用户的标识；
        # params，接口参数，如daily接口中start_date和end_date；
        # fields，字段列表，用于接口获取指定的字段，以逗号分隔，如"open,high,low,close"；

        :param api_name:
        :param fields:
        :param kwargs:
        :return:
        """
        req_params = {
            'api_name': api_name,
            'token': self._token,
            'params': kwargs,
            'fields': fields
        }

        res = requests.post(self._http_url, json=req_params, timeout=self._timeout, headers={'Connection': 'close'})
        if res is not None:
            result = json.loads(res.text)
            if result['error_code'] != 200:
                raise Exception(result['msg'])
            data = result['data']
            columns = data['fields']
            items = data['items']
            return pd.DataFrame(items, columns=columns)
        else:
            return pd.DataFrame()

    def __getattr__(self, name):
        return partial(self.query, name)


if __name__ == "__main__":
    tmp = DataApi(token="64f1fad23b7533faea99afa317f53752").query(api_name="laohuangli")
    print(tmp)


#!/usr/bin/env python
# _*_ coding: utf-8 _*_
# @Time : 2022/9/28 11:10
# @Author : justin.郑 3907721@qq.com
# @File : baidu_decrypt.py
# @desc : 百度解密

from typing import List, Dict, Tuple
from urllib.parse import urlencode, quote
from gopup.index.errors import ErrorCode, GopupError
from Crypto.Cipher import AES
from base64 import b64encode
import datetime
import requests
import json


headers = {
    'Host': 'index.baidu.com',
    'Connection': 'keep-alive',
    'X-Requested-With': 'XMLHttpRequest',
    'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.182 Safari/537.36',
}

ALL_KIND = ['all', 'pc', 'wise']


def decrypt_func(key: str, data: str) -> List[str]:
    """
        数据解密方法
    """
    a = key
    i = data
    n = {}
    s = []
    for o in range(len(a)//2):
        n[a[o]] = a[len(a)//2 + o]
    for r in range(len(data)):
        s.append(n[i[r]])
    return ''.join(s).split(',')


def http_get(url: str, cookies: str, cipher_text: str = "") -> str:
    """
        发送get请求, 程序中所有的get都是调这个方法
        如果想使用多cookies抓取, 和请求重试功能
        在这自己添加
    """
    _headers = headers.copy()
    _headers['Cookie'] = cookies
    if cipher_text:
        _headers["Cipher-Text"] = cipher_text
    try:
        response = requests.get(url, headers=_headers, timeout=30)
    except requests.Timeout:
        raise GopupError(ErrorCode.NETWORK_ERROR)
    if response.status_code != 200:
        raise GopupError(ErrorCode.NETWORK_ERROR)
    return response.text


def get_cipher_text(keyword: str) -> str:
    byte_list = [
        b"\x00", b"\x01", b"\x02", b"\x03", b"\x04", b"\x05", b"\x06", b"\x07",
        b"\x08", b"\x09", b"\x0a", b"\x0b", b"\x0c", b"\x0d", b"\x0e", b"\x0f",
        b"\x10"
    ]
    # 这个数是从acs-2057.js里写死的，但这个脚本请求时代时间戳，不确定是不是一个动态变化的脚本
    start_time = 1652338834776
    end_time = int(datetime.datetime.now().timestamp()*1000)

    wait_encrypted_data = {
        "ua": headers["User-Agent"],
        "url": quote(f"https://index.baidu.com/v2/main/index.html#/trend/{keyword}?words={keyword}"),
        "platform": "MacIntel",
        "clientTs": end_time,
        "version": "2.1.0"
    }
    password = b"yyqmyasygcwaiyaa"
    iv = b"1234567887654321"
    aes = AES.new(password, AES.MODE_CBC, iv)
    wait_encrypted_str = json.dumps(wait_encrypted_data).encode()
    filled_count = 16 - len(wait_encrypted_str) % 16
    wait_encrypted_str += byte_list[filled_count] * filled_count
    encrypted_str = aes.encrypt(wait_encrypted_str)
    cipher_text = f"{start_time}_{end_time}_{b64encode(encrypted_str).decode()}"
    return cipher_text


def get_encrypt_json(
    *,
    start_date: str,
    end_date: str,
    keywords: List[List[str]],
    type: str,
    area: int,
    cookies: str
) -> Dict:
    pre_url_map = {
        'search': 'http://index.baidu.com/api/SearchApi/index?',
        'live': 'http://index.baidu.com/api/LiveApi/getLive?',
        'news': 'http://index.baidu.com/api/NewsApi/getNewsIndex?',
        'feed': 'http://index.baidu.com/api/FeedSearchApi/getFeedIndex?'
    }

    pre_url = pre_url_map[type]
    word_list = [
        [{'name': keyword, 'wordType': 1} for keyword in keyword_list]
        for keyword_list in keywords
    ]
    if type == 'live':
        request_args = {
            'word': json.dumps(word_list),
            'region': area
        }
    else:
        request_args = {
            'word': json.dumps(word_list),
            'startDate': start_date,
            'endDate': end_date,
            'area': area
        }
    url = pre_url + urlencode(request_args)
    cipher_text = get_cipher_text(keywords[0][0])
    html = http_get(url, cookies, cipher_text=cipher_text)
    datas = json.loads(html)
    if datas['status'] == 10000:
        raise GopupError(ErrorCode.NO_LOGIN)
    if datas["status"] == 10001:
        raise GopupError(ErrorCode.REQUEST_LIMITED)
    if datas['status'] != 0:
        raise GopupError(ErrorCode.UNKNOWN, str(datas))
    return datas


def get_key(uniqid: str, cookies: str) -> str:
    url = 'http://index.baidu.com/Interface/api/ptbk?uniqid=%s' % uniqid
    html = http_get(url, cookies)
    datas = json.loads(html)
    key = datas['data']
    return key


def format_data(data: Dict, kind: str):
    """
        格式化堆在一起的数据
    """
    keyword = str(data['word'])
    start_date = datetime.datetime.strptime(data['all']['startDate'], '%Y-%m-%d')
    end_date = datetime.datetime.strptime(data['all']['endDate'], '%Y-%m-%d')
    date_list = []
    while start_date <= end_date:
        date_list.append(start_date)
        start_date += datetime.timedelta(days=1)

    # for kind in ALL_KIND:
    index_datas = data[kind]['data']
    for i, cur_date in enumerate(date_list):
        try:
            index_data = index_datas[i]
        except IndexError:
            index_data = ''
        formated_data = {
            'keyword': [keyword_info['name'] for keyword_info in json.loads(keyword.replace('\'', '"'))][0],
            'type': kind,
            'date': cur_date.strftime('%Y-%m-%d'),
            'index': index_data if index_data else '0'
        }
        yield formated_data


def format_data_feed(data: Dict):
    keyword = str(data['key'])
    start_date = datetime.datetime.strptime(data['startDate'], '%Y-%m-%d')
    end_date = datetime.datetime.strptime(data['endDate'], '%Y-%m-%d')
    date_list = []
    while start_date <= end_date:
        date_list.append(start_date)
        start_date += datetime.timedelta(days=1)

    index_datas = data['data']
    for i, cur_date in enumerate(date_list):
        try:
            index_data = index_datas[i]
        except IndexError:
            index_data = ''
        formated_data = {
            'keyword': [keyword_info['name'] for keyword_info in json.loads(keyword.replace('\'', '"'))][0],
            'date': cur_date.strftime('%Y-%m-%d'),
            'index': index_data if index_data else '0'
        }
        yield formated_data


def format_data_new(data: Dict):
    keyword = str(data['key'])
    start_date = datetime.datetime.strptime(data['startDate'], '%Y-%m-%d')
    end_date = datetime.datetime.strptime(data['endDate'], '%Y-%m-%d')
    date_list = []
    while start_date <= end_date:
        date_list.append(start_date)
        start_date += datetime.timedelta(days=1)

    index_datas = data['data']
    for i, cur_date in enumerate(date_list):
        try:
            index_data = index_datas[i]
        except IndexError:
            index_data = ''
        formated_data = {
            'keyword': [keyword_info['name'] for keyword_info in json.loads(keyword.replace('\'', '"'))][0],
            'date': cur_date.strftime('%Y-%m-%d'),
            'index': index_data if index_data else '0'
        }
        yield formated_data




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/13 17:36
# @Author  : justin.郑 3907721@qq.com
# @File    : franchise.py
# @Desc    : 商业特许经营信息

import pandas as pd
import requests
import ssl
ssl._create_default_https_context = ssl._create_unverified_context


def franchise_china():
    """
    中国-商业特许经营信息管理
    http://txjy.syggs.mofcom.gov.cn/
    :return: 中国-商业特许经营的所有企业
    :rtype: pandas.DataFrame
    """
    url = "http://txjy.syggs.mofcom.gov.cn/index.do"
    # file_url 历史数据文件, 主要是为了防止重复访问的速度和资源浪费问题
    file_url = "https://jfds-1252952517.cos.ap-chengdu.myqcloud.com/akshare/readme/franchise/franchise_china.csv"
    outer_df = pd.read_csv(file_url, encoding="gbk", index_col=0)
    try:
        for page in range(1, 5):
            payload = {
                "method": "entps",
                "province": "",
                "city": "",
                "cpf.cpage": str(page),
                "cpf.pagesize": "100",
            }
            headers = {
                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.61 Safari/537.36",
            }
            r = requests.get(url, params=payload, headers=headers)
            temp_df = pd.read_html(r.text)[1]
            inner_df = temp_df.iloc[:, 0].str.split("  ", expand=True)
            inner_df.columns = ["特许人名称", "备案时间", "地址"]
            outer_df = outer_df.append(inner_df, ignore_index=True)
    except:
        pass
    outer_df.drop_duplicates(inplace=True)
    return outer_df


if __name__ == "__main__":
    franchise_china_df = franchise_china()
    print(franchise_china_df)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/27 0027
# @Author  : justin.郑 3907721@qq.com
# @File    : date_utils.py
# @Desc    : 日期管理工具

import datetime
import time
import pandas as pd


def year_qua(date):
    mon = date[5:7]
    mon = int(mon)
    return [date[0:4], _quar(mon)]


def _quar(mon):
    if mon in [1, 2, 3]:
        return '1'
    elif mon in [4, 5, 6]:
        return '2'
    elif mon in [7, 8, 9]:
        return '3'
    elif mon in [10, 11, 12]:
        return '4'
    else:
        return None


def today():
    """
    获取当天日期 年-月-日
    """
    day = datetime.datetime.today().date()
    return str(day)


def get_year():
    """
    获取当年
    """
    year = datetime.datetime.today().year
    return year


def get_month():
    """
    获取当月
    """
    month = datetime.datetime.today().month
    return month


def get_hour():
    """
    获取当前小时
    """
    return datetime.datetime.today().hour


def today_last_year():
    """
    获取去年的今天日期
    """
    lasty = datetime.datetime.today().date() + datetime.timedelta(-365)
    return str(lasty)


def day_last_week(days=-7):
    """
    获得前几天的日期
    :param days: 前几天
    """
    lasty = datetime.datetime.today().date() + datetime.timedelta(days)
    return str(lasty)


def day_last_date(date, days=-1):
    """
    获得某天的之前一天日期
    :param date: 日期
    """
    dd = datetime.datetime.strptime(date, "%Y-%m-%d")
    lasty = dd + datetime.timedelta(days)
    return str(lasty)[0:10]


def get_now():
    """
    获得当前时间
    """
    return time.strftime('%Y-%m-%d %H:%M:%S')


def int2time(timestamp):
    datearr = datetime.datetime.utcfromtimestamp(timestamp)
    timestr = datearr.strftime("%Y-%m-%d %H:%M:%S")
    return timestr


def diff_day(start=None, end=None):
    """
    两个日期间 相差天数
    :param start: 开始日期
    :param end:   截止日期
    :return: 相差天数
    """
    d1 = datetime.datetime.strptime(end, '%Y-%m-%d')
    d2 = datetime.datetime.strptime(start, '%Y-%m-%d')
    delta = d1 - d2
    return delta.days


def get_quarts(start, end):
    idx = pd.period_range('Q'.join(year_qua(start)), 'Q'.join(year_qua(end)),
                          freq='Q-JAN')
    return [str(d).split('Q') for d in idx][::-1]


def trade_cal():
    '''
    交易日历
    isOpen=1是交易日，isOpen=0为休市
    '''
    ALL_CAL_FILE = 'http://file.tushare.org/tsdata/calAll.csv'
    df = pd.read_csv(ALL_CAL_FILE)
    return df


def is_holiday(date):
    '''
    判断是否为交易日，返回True or False
    '''
    df = trade_cal()
    holiday = df[df.isOpen == 0]['calendarDate'].values
    if isinstance(date, str):
        today = datetime.datetime.strptime(date, '%Y-%m-%d')

    if today.isoweekday() in [6, 7] or str(date) in holiday:
        return True
    else:
        return False


def last_tddate():
    today = datetime.datetime.today().date()
    today = int(today.strftime("%w"))
    if today == 0:
        return day_last_week(-2)
    else:
        return day_last_week(-1)


def tt_dates(start='', end=''):
    startyear = int(start[0:4])
    endyear = int(end[0:4])
    dates = [d for d in range(startyear, endyear + 1, 2)]
    return dates


def _random(n=13):
    from random import randint
    start = 10 ** (n - 1)
    end = (10 ** n) - 1
    return str(randint(start, end))


def get_q_date(year=None, quarter=None):
    dt = {'1': '-03-31', '2': '-06-30', '3': '-09-30', '4': '-12-31'}
    return '%s%s' % (str(year), dt[str(quarter)])
 

if __name__ == "__main__":
    tmp = day_last_date('2017-03-27')
    # tmp = tt_dates('2017-03-27', '2021-03-30')
    print(tmp)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/16 0016
# @Author  : justin.郑 3907721@qq.com
# @File    : index_google.py
# @Desc    : 谷歌相关数据接口

import ast
import pandas as pd
import requests
from gopup.index.cons import headers
from gopup.index.google_request import TrendReq
from gopup.utils.date_utils import int2time


def google_index(keyword="python", start_date="2019-12-01", end_date="2019-12-04"):
    """
    返回指定区间的谷歌指数
    :param keyword:
    :param start_date:  2019-12-10T10
    :param end_date:    2019-12-10T23
    :return:
    """
    try:
        pytrends = TrendReq(hl="en-US", tz=360)
        kw_list = [keyword]
        pytrends.build_payload(
            kw_list, cat=0, timeframe=start_date + " " + end_date, geo="", gprop=""
        )
        search_df = pytrends.interest_over_time()
        search_df['value'] = search_df[keyword]
        search_df['date'] = search_df.index
        res_df = search_df.drop(['isPartial', keyword], axis=1)
        return res_df
    except:
        return None


def google_fact_check(keyword, offset=0, limit=100, hl=None):
    """
    谷歌事实查证
    :param keyword: 查证关键词
    :param offset:  起始数
    :param limit:   每次获取数量 300篇最大
    :param hl:      语言 默认为全部；中文：zh，英文：en ……
    :return:
        DataFrame
            title       信息标题
            url         信息链接
            type        查证类型
            remark      查证摘要
            check       查核机构
            source_data 信息来源
            news_img    信息图像
            value       事实查证值
            date        日期时间
    """
    try:
        url = "https://toolbox.google.com/factcheck/api/search"
        data = {
            "hl": hl,
            "query": keyword,
            "num_results": limit,
            "offset": offset
        }
        r = requests.get(url, params=data, headers=headers)
        if r.status_code == 200:
            con = r.text[6:]
            con = con.replace("\n", "").replace("null", "'-'")
            con_list = ast.literal_eval(con)[0][1]
            res_list = []
            for i in range(0, len(con_list)):
                con = con_list[i]
                tmp = {
                    "title": con[0][0],
                    "type": con[0][3][0][3],
                    "url": con[0][3][0][1],
                    "remark": con[0][3][0][8],
                    "check": con[0][3][0][0][0],
                    "source_data": listToStr(con[0][3][0][0]),
                    "date": "-" if con[0][3][0][2] == "-" else int2time(int(con[0][3][0][2])),
                    "news_img": con[1],
                    "value": con[2],
                }
                res_list.append(tmp)
        res_pd = pd.DataFrame(res_list)
        return res_pd
    except:
        return None


def listToStr(lists):
    res = []
    for li in lists:
        if not isinstance(li, list):
            res.append(li)
    if len(res) > 0:
        return ','.join(res)
    return None


if __name__ == "__main__":
    google_index_df = google_index(
        keyword="AI", start_date="2019-12-10T10", end_date="2019-12-10T23")
    print(google_index_df)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/20 0020
# @Author  : justin.郑 3907721@qq.com
# @File    : cons.py
# @Desc    : 指数配置文件


# weibo-user-agent
index_weibo_headers = {
    "User-Agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 11_0 like Mac OS X) AppleWebKit/604.1.38 (KHTML, like Gecko) Version/11.0 Mobile/15A372 Safari/604.1",
    "Referer": "http://data.weibo.com/index/newindex",
    "Accept": "application/json",
    "Origin": "https://data.weibo.com",
}
 

headers = {
    "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.88 Safari/537.36",
}

index_toutiao_headers = {
    "User-Agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 11_0 like Mac OS X) AppleWebKit/604.1.38 (KHTML, like Gecko) Version/11.0 Mobile/15A372 Safari/604.1",
    'Content-Type': 'application/json',

}


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/27 0027
# @Author  : justin.郑 3907721@qq.com
# @File    : shibor.py
# @Desc    : 利率数据
# 上海银行间同业拆放利率（Shibor）数据接口

import json
import pandas as pd
import numpy as np
import requests
from gopup.economic import cons
from gopup.utils import date_utils as du


def shibor_data(year=None):
    """
    获取上海银行间同业拆放利率（Shibor）
    Parameters
    ------
      year:年份(int)

    Return
    ------
    date:日期
    ON:隔夜拆放利率
    1W:1周拆放利率
    2W:2周拆放利率
    1M:1个月拆放利率
    3M:3个月拆放利率
    6M:6个月拆放利率
    9M:9个月拆放利率
    1Y:1年拆放利率

    http://www.shibor.org/shibor/web/html/downLoad.html?nameNew=Historical_Shibor_Data_2019.xls&downLoadPath=data&nameOld=Shibor数据2019.xls&shiborSrc=http://www.shibor.org/shibor/
    """
    year = du.get_year() if year is None else year
    lab = cons.SHIBOR_TYPE['Shibor']
    try:
        url = cons.SHIBOR_DATA_URL % (cons.P_TYPE['http'], cons.DOMAINS['shibor'],
                                               cons.PAGES['dw'], 'Shibor',
                                               year, lab,
                                               year)
        herder = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
            "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive"
        }

        r = requests.get(url, headers=herder)
        df = pd.read_excel(r.content)
        df.columns = cons.SHIBOR_COLS
        df['date'] = df['date'].map(lambda x: x.date())
        return df
    except Exception as e:
        return None


def shibor_quote_data(year=None):
    """
    获取Shibor银行报价数据
    Parameters
    ------
      year:年份(int)

    Return
    ------
    date:日期
    bank:报价银行名称
    ON:隔夜拆放利率
    ON_B:隔夜拆放买入价
    ON_A:隔夜拆放卖出价
    1W_B:1周买入
    1W_A:1周卖出
    2W_B:买入
    2W_A:卖出
    1M_B:买入
    1M_A:卖出
    3M_B:买入
    3M_A:卖出
    6M_B:买入
    6M_A:卖出
    9M_B:买入
    9M_A:卖出
    1Y_B:买入
    1Y_A:卖出
    """
    year = du.get_year() if year is None else year
    lab = cons.SHIBOR_TYPE['Quote']
    try:
        url = cons.SHIBOR_DATA_URL % (cons.P_TYPE['http'], cons.DOMAINS['shibor'],
                                      cons.PAGES['dw'], 'Quote',
                                      year, lab,
                                      year)
        herder = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
            "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive"
        }

        r = requests.get(url, headers=herder)
        df = pd.read_excel(r.content)
        df.columns = cons.SHIBOR_Q_COLS
        df['date'] = df['date'].map(lambda x: x.date())
        return df
    except:
        return None


def shibor_ma_data(year=None):
    """
    获取Shibor均值数据
    Parameters
    ------
      year:年份(int)

    Return
    ------
    date:日期
       其它分别为各周期5、10、20均价
    """
    year = du.get_year() if year is None else year
    lab = cons.SHIBOR_TYPE['Tendency']
    try:
        url = cons.SHIBOR_DATA_URL % (cons.P_TYPE['http'], cons.DOMAINS['shibor'],
                                               cons.PAGES['dw'], 'Shibor_Tendency',
                                               year, lab,
                                               year)
        herder = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
            "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive"
        }

        r = requests.get(url, headers=herder)
        df = pd.read_excel(r.content)
        df.columns = cons.SHIBOR_MA_COLS
        df['date'] = df['date'].map(lambda x: x.date())
        return df
    except:
        return None


def lpr_data(startDate, endDate):
    """
    获取贷款市场报价利率（LPR）
    Parameters
    ------
      startDate:起止日期(str)
      endDate:截止日期(str)

    Return
    ------
    showDateCN:日期
    1Y:1年贷款基础利率
    5Y:5年贷款基础利率
    """

    try:
        url = cons.LPR_DATA_URL

        herder = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
            "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive"
        }

        data = {
            "lang": "CN",
            "strStartDate": startDate,
            "strEndDate": endDate
        }

        r = requests.post(url, data=data, headers=herder)
        data_dict = json.loads(r.text)['records']
        df = pd.DataFrame(data_dict)
        return df
    except:
        return None


if __name__ == "__main__":
    tmp = shibor_data(2019)
    print(tmp)
 




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/24 0024
# @Author  : justin.郑 3907721@qq.com
# @File    : marco_cn.py
# @Desc    : 中国宏观数据

import pandas as pd
import numpy as np
import re
import json
import requests
from gopup.economic import cons


def marco_cmlrd():
    """
    中国宏观杠杆率数据
    :return:
    """
    url = "http://114.115.232.154:8080/handler/download.ashx"
    excel_data = pd.read_excel(url, sheet_name="Data", header=0, skiprows=1)
    excel_data["Period"] = pd.to_datetime(excel_data["Period"]).dt.strftime("%Y-%m")
    excel_data.columns = [
        "年份",
        "居民部门",
        "非金融企业部门",
        "政府部门",
        "中央政府",
        "地方政府",
        "实体经济部门",
        "金融部门资产方",
        "金融部门负债方",
    ]
    return excel_data


def get_gdp_quarter():
    """
    获取季度国内生产总值数据
    --------
    DataFrame
        month :统计月份
        cpi : "季度", "国内生产总值 绝对值(亿元)", "国内生产总值 同比增长", "第一产业 绝对值(亿元)", "第一产业 同比增长", "第二产业 绝对值(亿元)", "第二产业 同比增长", "第三产业 绝对值(亿元)", "第三产业 同比增长"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "20"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[")+2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["季度", "国内生产总值 绝对值(亿元)", "国内生产总值 同比增长", "第一产业 绝对值(亿元)", "第一产业 同比增长", "第二产业 绝对值(亿元)", "第二产业 同比增长", "第三产业 绝对值(亿元)", "第三产业 同比增长"]
    data_df = pd.DataFrame(res_list, columns=columns)
    return data_df


def get_cpi():
    """
        获取居民消费价格指数数据（CPI）
    --------
    DataFrame
        month :统计月份
        cpi : "月份", "全国当月", "全国同比增长", "全国环比增长", "全国累计", "城市当月", "城市同比增长", "城市环比增长", "城市累计", "农村当月", "农村同比增长", "农村环比增长", "农村累计"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "19"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[")+2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["月份", "全国当月", "全国同比增长", "全国环比增长", "全国累计", "城市当月", "城市同比增长", "城市环比增长", "城市累计", "农村当月", "农村同比增长", "农村环比增长", "农村累计"]
    data_df = pd.DataFrame(res_list, columns=columns)
    return data_df


def get_ppi():
    """
        获取工业品出厂价格指数数据
    --------
    DataFrame
        "月份", "当月", "当月同比增长", "累计"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "22"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[") + 2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["月份", "当月", "当月同比增长", "累计"]
    data_df = pd.DataFrame(res_list, columns=columns)
    return data_df


def get_pmi():
    """
        获取采购经理人指数(PMI)
    --------
    DataFrame
        "月份", "制造业指数", "制造业同比增长", "非制造业指数", "非制造业同比增长"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "21"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[") + 2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["月份", "制造业指数", "制造业同比增长", "非制造业指数", "非制造业同比增长"]
    data_df = pd.DataFrame(res_list, columns=columns)
    return data_df


def get_rrr():
    """
        获取存款准备金率数据
    --------
    DataFrame
        "公布时间", "生效时间", "大型金融机构 调整前", "大型金融机构 调整后", "大型金融机构 调整幅度", "中小型金融机构 调整前", "中小型金融机构 调整后", "中小型金融机构 调整幅度", "备注", "消息公布次日指数涨跌 上证", "消息公布次日指数涨跌 深证"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "23"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[") + 2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["公布时间", "生效时间", "大型金融机构 调整前", "大型金融机构 调整后", "大型金融机构 调整幅度", "中小型金融机构 调整前", "中小型金融机构 调整后", "中小型金融机构 调整幅度", "备注", "消息公布次日指数涨跌 上证", "消息公布次日指数涨跌 深证"]
    data_df = pd.DataFrame(res_list, columns=columns)
    return data_df


def get_money_supply():
    """
        获取货币供应量数据
    --------
    DataFrame
        "月份", "货币和准货币(M2) 数量(亿元)", "货币和准货币(M2) 同比增长", "货币和准货币(M2) 环比增长", "货币(M1) 数量(亿元)", "货币(M1) 同比增长	", "货币(M1) 环比增长", "流通中的现金(M0) 数量(亿元)", "流通中的现金(M0) 同比增长", "流通中的现金(M0) 环比增长"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "11"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[") + 2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["月份", "货币和准货币(M2) 数量(亿元)", "货币和准货币(M2) 同比增长", "货币和准货币(M2) 环比增长", "货币(M1) 数量(亿元)", "货币(M1) 同比增长	", "货币(M1) 环比增长", "流通中的现金(M0) 数量(亿元)", "流通中的现金(M0) 同比增长", "流通中的现金(M0) 环比增长"]
    data_df = pd.DataFrame(res_list, columns=columns)
    return data_df


def get_gold_and_foreign_reserves():
    """
    获取外汇储备
    Returns
    -------
    DataFrame
        "月份", "国家外汇储备(亿美元) 数值", "国家外汇储备(亿美元) 同比", "国家外汇储备(亿美元) 环比", "黄金储备(万盎司) 数值", "黄金储备(万盎司) 同比", "黄金储备(万盎司) 环比"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "16"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[") + 2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["月份", "国家外汇储备(亿美元) 数值", "国家外汇储备(亿美元) 同比", "国家外汇储备(亿美元) 环比", "黄金储备(万盎司) 数值", "黄金储备(万盎司) 同比", "黄金储备(万盎司) 环比"]
    data_df = pd.DataFrame(res_list, columns=columns)
    return data_df


# 0.3.2
def get_industrial_growth():
    """
    获取工业增加值增长
    Returns
    -------
    DataFrame
        "月份", "同比增长%", "累计增长%"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "0"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[") + 2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["月份", "同比增长%", "累计增长%"]
    data_df = pd.DataFrame(res_list, columns=columns)
    return data_df


def get_fiscal_revenue():
    """
    获取财政收入
    Returns
    -------
    DataFrame
        "月份、当月(亿元)、同比增长、环比增长、累计(亿元)、同比增长"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "14"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[") + 2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["月份", "当月(亿元)", "同比增长", "环比增长", "累计(亿元)", "同比增长"]
    data_df = pd.DataFrame(res_list, columns=columns)
    return data_df


def get_consumer_total():
    """
    获取社会消费品零售总额
    Returns
    -------
    DataFrame
        "月份、当月(亿元)、同比增长、环比增长、累计(亿元)、同比增长"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "5"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[") + 2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["月份", "当月(亿元)", "同比增长", "环比增长", "累计(亿元)", "同比增长"]
    data_df = pd.DataFrame(res_list, columns=columns)
    return data_df


def get_credit_data():
    """
    获取信贷数据
    Returns
    -------
    DataFrame
        "月份、当月(亿元)、同比增长、环比增长、累计(亿元)、同比增长"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "7"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[") + 2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["月份", "当月(亿元)", "同比增长", "环比增长", "累计(亿元)", "同比增长"]
    data_df = pd.DataFrame(res_list, columns=columns)
    return data_df


def get_fdi_data():
    """
    获取外商直接投资数据(FDI)
    Returns
    -------
    DataFrame
        "月份、当月(亿元)、同比增长、环比增长、累计(亿元)、同比增长"
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "ZGZB",
        "p": "1",
        "ps": "200",
        "mkt": "15"
    }
    r = requests.get(url=url, params=params)
    data_text = r.text
    tmp_list = data_text[data_text.find("[") + 2: -3]
    tmp_list = tmp_list.split('","')
    res_list = []
    for li in tmp_list:
        res_list.append(li.split(','))
    columns = ["月份", "当月(十万元)", "同比增长", "环比增长", "累计(十万元)", "同比增长"]
    data_df = pd.DataFrame(res_list, columns=columns)
    # data_df['当月(亿元)'] = data_df['当月(亿元)'].map(lambda x: int(x)/100000)
    # data_df['累计(亿元)'] = data_df['累计(亿元)'].map(lambda x: int(x)/100000)
    return data_df


if __name__ == '__main__':
    tmp = get_fdi_data()
    print(tmp)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/19 0019
# @Author  : justin.郑 3907721@qq.com
# @File    : pro_data.py
# @Desc    :

from gopup.pro import client
from gopup.utils import utils_pass


def pro_api(token='', timeout=30):
    """
    初始化pro API,
    第一次可以通过gp.set_token('your token')来记录自己的token凭证，
    临时token可以通过本参数传入
    """
    if token == '' or token is None:
        token = utils_pass.get_token()
    if token is not None and token != '':
        pro = client.DataApi(token=token, timeout=timeout)
        return pro
    else:
        raise Exception('api init error.')





#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/21 0021
# @Author  : justin.郑 3907721@qq.com
# @File    : area_baidu.py
# @Desc    : 获取百度迁徙数据

import json
import requests
import pandas as pd
from gopup.event.cons import province_dict, city_dict


def migration_area_baidu(area="武汉市", indicator="move_in", date="20200201"):
    """
    百度地图慧眼-百度迁徙-XXX迁入地详情
    百度地图慧眼-百度迁徙-XXX迁出地详情
    以上展示 top100 结果，如不够 100 则展示全部
    迁入来源地比例: 从 xx 地迁入到当前区域的人数与当前区域迁入总人口的比值
    迁出目的地比例: 从当前区域迁出到 xx 的人口与从当前区域迁出总人口的比值
    https://qianxi.baidu.com/?from=shoubai#city=0
    :param area: 可以输入 省份 或者 具体城市 但是需要用全称
    :type area: str
    :param indicator: move_in 迁入 move_out 迁出
    :type indicator: str
    :param date: 查询的日期 20200101以后的时间
    :type date: str
    :return: 迁入地详情/迁出地详情的前50个
    :rtype: pandas.DataFrame
    """
    try:
        if area == "全国":
            payload = {
                "dt": "country",
                "id": 0,
                "type": indicator,
                "date": date,
            }
        else:
            city_dict.update(province_dict)
            inner_dict = dict(zip(city_dict.values(), city_dict.keys()))
            if inner_dict[area] in province_dict.keys():
                dt_flag = "province"
            else:
                dt_flag = "city"
            payload = {
                "dt": dt_flag,
                "id": inner_dict[area],
                "type": indicator,
                "date": date,
            }

        url = "https://huiyan.baidu.com/migration/cityrank.jsonp"
        r = requests.get(url, params=payload)
        json_data = json.loads(r.text[r.text.find("({") + 1 : r.text.rfind(");")])
        return pd.DataFrame(json_data["data"]["list"])
    except:
        return None


def migration_scale_baidu(area="武汉市", indicator="move_out", date="20210112"):
    """
    百度地图慧眼-百度迁徙-迁徙规模
    * 迁徙规模指数：反映迁入或迁出人口规模，城市间可横向对比
    * 城市迁徙边界采用该城市行政区划，包含该城市管辖的区、县、乡、村
    https://qianxi.baidu.com/?from=shoubai#city=0
    :param area: 可以输入 省份 或者 具体城市 但是需要用全称
    :type area: str
    :param indicator: move_in 迁入 move_out 迁出
    :type indicator: str
    :param date: 结束查询的日期 20200101 以后的时间
    :type end_date: str
    :return: 时间序列的迁徙规模指数
    :rtype: pandas.DataFrame
    """
    try:
        if area == "全国":
            payload = {
                "dt": "country",
                "id": 0,
                "type": indicator,
                "date": date
            }
        else:
            city_dict.update(province_dict)
            inner_dict = dict(zip(city_dict.values(), city_dict.keys()))
            try:
                if inner_dict[area] in province_dict.keys():
                    dt_flag = "province"
                else:
                    dt_flag = "city"

                payload = {
                    "dt": dt_flag,
                    "id": inner_dict[area],
                    "type": indicator,
                    "date": date
                }
            except Exception as e:
                return "省份 或者 具体城市名 错误"
        url = "https://huiyan.baidu.com/migration/historycurve.jsonp"
        r = requests.get(url, params=payload)
        json_data = json.loads(r.text[r.text.find("({") + 1 : r.text.rfind(");")])
        temp_df = pd.DataFrame.from_dict(json_data["data"]["list"], orient="index")
        temp_df.index = pd.to_datetime(temp_df.index)
        temp_df.columns = ["迁徙规模指数"]
        return temp_df
    except:
        return None


if __name__ == "__main__":
    tmp = migration_scale_baidu(area="武汉", indicator="move_out")
    print(tmp)





#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/1/23 0023
# @Author  : justin.郑 3907721@qq.com
# @File    : weibo.py
# @Desc    : 微博

import json
import math
import sys
import requests
import warnings
import random
from lxml import etree
from time import sleep
from tqdm import tqdm
from collections import OrderedDict
from datetime import date, datetime, timedelta
import pandas as pd
warnings.filterwarnings("ignore")


class Weibo(object):
    def __init__(self, cookie="", since_date=None, filter=1):
        # 初始化
        cookie = cookie  # 微博cookie，可填可不填
        user_agent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.111 Safari/537.36'
        self.headers = {'User_Agent': user_agent, 'Cookie': cookie}
        self.query = ''
        # 取值范围为0、1,程序默认值为0,代表要爬取用户的全部微博,1代表只爬取用户的原创微博
        self.filter = filter
        self.start_page = 1  # 开始爬的页，如果中途被限制而结束可以用此定义开始页码
        self.user = {}  # 存储目标微博用户信息
        self.got_count = 0  # 存储爬取到的微博数
        self.weibo = []  # 存储爬取到的所有微博信息
        self.weibo_id_list = []  # 存储爬取到的所有微博id

        if since_date is None:
            dayago = (datetime.now() - timedelta(days=15))
            self.since_date = dayago.strftime("%Y-%m-%d")
        else:
            self.since_date = since_date

    def get_json(self, params):
        """获取网页中json数据"""
        url = 'https://m.weibo.cn/api/container/getIndex?'
        r = requests.get(url,
                         params=params,
                         headers=self.headers,
                         verify=False)
        return r.json()

    def get_weibo_json(self, page):
        """获取网页中微博json数据"""
        params = {
            'container_ext': 'profile_uid:' + str(self.user_id),
            'containerid': '100103type=401&q=' + self.query,
            'page_type': 'searchall'
        } if self.query else {
            'containerid': '107603' + str(self.user_id)
        }
        params['page'] = page
        js = self.get_json(params)
        return js

    def standardize_info(self, weibo):
        """标准化信息，去除乱码"""
        for k, v in weibo.items():
            if 'bool' not in str(type(v)) and 'int' not in str(
                    type(v)) and 'list' not in str(
                        type(v)) and 'long' not in str(type(v)):
                weibo[k] = v.replace(u'\u200b', '').encode(
                    sys.stdout.encoding, 'ignore').decode(sys.stdout.encoding)
        return weibo

    def get_user_info(self):
        """获取用户信息"""
        params = {'containerid': '100505' + str(self.user_id)}
        js = self.get_json(params)
        if js['ok']:
            info = js['data']['userInfo']
            user_info = OrderedDict()
            user_info['用户id'] = self.user_id
            user_info['用户昵称'] = info.get('screen_name', '')
            gender = info.get('gender', '')
            user_info['性别'] = u'女' if gender == 'f' else u'男'
            params = {
                'containerid':
                '230283' + str(self.user_id) + '_-_INFO'
            }
            zh_list = [
                u'生日', u'所在地', u'小学', u'初中', u'高中', u'大学', u'公司', u'注册时间',
                u'阳光信用'
            ]
            en_list = [
                'birthday', 'location', 'education', 'education', 'education',
                'education', 'company', 'registration_time', 'sunshine'
            ]
            for i in zh_list:
                user_info[i] = ''
            js = self.get_json(params)
            if js['ok']:
                cards = js['data']['cards']
                if isinstance(cards, list) and len(cards) > 1:
                    card_list = cards[0]['card_group'] + cards[1]['card_group']
                    for card in card_list:
                        if card.get('item_name') in zh_list:
                            # user_info[zh_list[zh_list.index(card.get('item_name'))]] = card.get('item_content', '')
                            user_info[card.get('item_name')] = card.get('item_content', '')
            user_info['微博数'] = info.get('statuses_count', 0)
            user_info['粉丝数'] = info.get('followers_count', 0)
            user_info['关注数'] = info.get('follow_count', 0)
            user_info['描述'] = info.get('description', '')
            user_info['网址'] = info.get('profile_url', '')
            user_info['头像'] = info.get('profile_image_url', '')
            user_info['头像原图'] = info.get('avatar_hd', '')
            user_info['urank'] = info.get('urank', 0)
            user_info['mbrank'] = info.get('mbrank', 0)
            user_info['是否认证'] = info.get('verified', False)
            user_info['认证类型'] = info.get('verified_type', -1)
            user_info['微博认证'] = info.get('verified_reason', '')
            user = self.standardize_info(user_info)
            self.user = user

    def get_page_count(self):
        """获取微博页数"""
        try:
            weibo_count = self.user['微博数']
            page_count = int(math.ceil(weibo_count / 10.0))
            return page_count
        except KeyError:
            pass

    def get_long_weibo(self, id):
        """获取长微博"""
        for i in range(5):
            url = 'https://m.weibo.cn/detail/%s' % id
            html = requests.get(url, headers=self.headers, verify=False).text
            html = html[html.find('"status":'):]
            html = html[:html.rfind('"hotScheme"')]
            html = html[:html.rfind(',')]
            html = '{' + html + '}'
            js = json.loads(html, strict=False)
            weibo_info = js.get('status')
            if weibo_info:
                weibo = self.parse_weibo(weibo_info)
                return weibo
            sleep(random.randint(6, 10))

    def get_location(self, selector):
        """获取微博发布位置"""
        location_icon = 'timeline_card_small_location_default.png'
        span_list = selector.xpath('//span')
        location = ''
        for i, span in enumerate(span_list):
            if span.xpath('img/@src'):
                if location_icon in span.xpath('img/@src')[0]:
                    location = span_list[i + 1].xpath('string(.)')
                    break
        return location

    def get_article_url(self, selector):
        """获取微博中头条文章的url"""
        article_url = ''
        text = selector.xpath('string(.)')
        if text.startswith(u'发布了头条文章'):
            url = selector.xpath('//a/@data-url')
            if url and url[0].startswith('http://t.cn'):
                article_url = url[0]
        return article_url

    def get_pics(self, weibo_info):
        """获取微博原始图片url"""
        if weibo_info.get('pics'):
            pic_info = weibo_info['pics']
            pic_list = [pic['large']['url'] for pic in pic_info]
            pics = ','.join(pic_list)
        else:
            pics = ''
        return pics

    def string_to_int(self, string):
        """字符串转换为整数"""
        if isinstance(string, int):
            return string
        elif string.endswith(u'万+'):
            string = int(string[:-2] + '0000')
        elif string.endswith(u'万'):
            string = int(string[:-1] + '0000')
        return int(string)

    def get_topics(self, selector):
        """获取参与的微博话题"""
        span_list = selector.xpath("//span[@class='surl-text']")
        topics = ''
        topic_list = []
        for span in span_list:
            text = span.xpath('string(.)')
            if len(text) > 2 and text[0] == '#' and text[-1] == '#':
                topic_list.append(text[1:-1])
        if topic_list:
            topics = ','.join(topic_list)
        return topics

    def get_at_users(self, selector):
        """获取@用户"""
        a_list = selector.xpath('//a')
        at_users = ''
        at_list = []
        for a in a_list:
            if '@' + a.xpath('@href')[0][3:] == a.xpath('string(.)'):
                at_list.append(a.xpath('string(.)')[1:])
        if at_list:
            at_users = ','.join(at_list)
        return at_users

    def get_live_photo(self, weibo_info):
        """获取live photo中的视频url"""
        live_photo_list = []
        live_photo = weibo_info.get('pic_video')
        if live_photo:
            prefix = 'https://video.weibo.com/media/play?livephoto=//us.sinaimg.cn/'
            for i in live_photo.split(','):
                if len(i.split(':')) == 2:
                    url = prefix + i.split(':')[1] + '.mov'
                    live_photo_list.append(url)
            return live_photo_list

    def get_video_url(self, weibo_info):
        """获取微博视频url"""
        video_url = ''
        video_url_list = []
        if weibo_info.get('page_info'):
            if weibo_info['page_info'].get('media_info') and weibo_info[
                    'page_info'].get('type') == 'video':
                media_info = weibo_info['page_info']['media_info']
                video_url = media_info.get('mp4_720p_mp4')
                if not video_url:
                    video_url = media_info.get('mp4_hd_url')
                    if not video_url:
                        video_url = media_info.get('mp4_sd_url')
                        if not video_url:
                            video_url = media_info.get('stream_url_hd')
                            if not video_url:
                                video_url = media_info.get('stream_url')
        if video_url:
            video_url_list.append(video_url)
        live_photo_list = self.get_live_photo(weibo_info)
        if live_photo_list:
            video_url_list += live_photo_list
        return ';'.join(video_url_list)

    def parse_weibo(self, weibo_info):
        weibo = OrderedDict()
        if weibo_info['user']:
            weibo['user_id'] = weibo_info['user']['id']
            weibo['screen_name'] = weibo_info['user']['screen_name']
        else:
            weibo['user_id'] = ''
            weibo['screen_name'] = ''
        weibo['id'] = int(weibo_info['id'])
        weibo['bid'] = weibo_info['bid']
        text_body = weibo_info['text']
        selector = etree.HTML(text_body)
        weibo['text'] = etree.HTML(text_body).xpath('string(.)')
        weibo['article_url'] = self.get_article_url(selector)
        weibo['pics'] = self.get_pics(weibo_info)
        weibo['video_url'] = self.get_video_url(weibo_info)
        weibo['location'] = self.get_location(selector)
        weibo['created_at'] = weibo_info['created_at']
        weibo['source'] = weibo_info['source']
        weibo['attitudes_count'] = self.string_to_int(
            weibo_info.get('attitudes_count', 0))
        weibo['comments_count'] = self.string_to_int(
            weibo_info.get('comments_count', 0))
        weibo['reposts_count'] = self.string_to_int(
            weibo_info.get('reposts_count', 0))
        weibo['topics'] = self.get_topics(selector)
        weibo['at_users'] = self.get_at_users(selector)
        return self.standardize_info(weibo)

    def standardize_date(self, created_at):
        """标准化微博发布时间"""
        if u'刚刚' in created_at:
            created_at = datetime.now().strftime('%Y-%m-%d')
        elif u'分钟' in created_at:
            minute = created_at[:created_at.find(u'分钟')]
            minute = timedelta(minutes=int(minute))
            created_at = (datetime.now() - minute).strftime('%Y-%m-%d')
        elif u'小时' in created_at:
            hour = created_at[:created_at.find(u'小时')]
            hour = timedelta(hours=int(hour))
            created_at = (datetime.now() - hour).strftime('%Y-%m-%d')
        elif u'昨天' in created_at:
            day = timedelta(days=1)
            created_at = (datetime.now() - day).strftime('%Y-%m-%d')
        else:
            created_at = created_at.replace('+0800 ', '')
            temp = datetime.strptime(created_at, '%c')
            created_at = datetime.strftime(temp, '%Y-%m-%d')
        return created_at

    def get_one_weibo(self, info):
        """获取一条微博的全部信息"""
        try:
            weibo_info = info['mblog']
            weibo_id = weibo_info['id']
            retweeted_status = weibo_info.get('retweeted_status')
            is_long = True if weibo_info.get('pic_num') > 9 else weibo_info.get('isLongText')
            if retweeted_status and retweeted_status.get('id'):  # 转发
                retweet_id = retweeted_status.get('id')
                is_long_retweet = retweeted_status.get('isLongText')
                if is_long:
                    weibo = self.get_long_weibo(weibo_id)
                    if not weibo:
                        weibo = self.parse_weibo(weibo_info)
                else:
                    weibo = self.parse_weibo(weibo_info)
                if is_long_retweet:
                    retweet = self.get_long_weibo(retweet_id)
                    if not retweet:
                        retweet = self.parse_weibo(retweeted_status)
                else:
                    retweet = self.parse_weibo(retweeted_status)
                retweet['created_at'] = self.standardize_date(retweeted_status['created_at'])
                weibo['retweet'] = retweet
            else:  # 原创
                if is_long:
                    weibo = self.get_long_weibo(weibo_id)
                    if not weibo:
                        weibo = self.parse_weibo(weibo_info)
                else:
                    weibo = self.parse_weibo(weibo_info)
            weibo['created_at'] = self.standardize_date(weibo_info['created_at'])
            return weibo
        except Exception as e:
            print(str(e))

    def is_pinned_weibo(self, info):
        """判断微博是否为置顶微博"""
        weibo_info = info['mblog']
        title = weibo_info.get('title')
        if title and title.get('text') == u'置顶':
            return True
        else:
            return False

    def get_one_page(self, page):
        """获取一页的全部微博"""
        try:
            js = self.get_weibo_json(page)
            if js['ok']:
                weibos = js['data']['cards']
                if self.query:
                    weibos = weibos[0]['card_group']
                for w in weibos:
                    if w['card_type'] == 9:
                        wb = self.get_one_weibo(w)
                        if wb:
                            if wb['id'] in self.weibo_id_list:
                                continue
                            created_at = datetime.strptime(
                                wb['created_at'], '%Y-%m-%d')
                            since_date = datetime.strptime(
                                self.since_date, '%Y-%m-%d')
                            if created_at < since_date:
                                if self.is_pinned_weibo(w):
                                    continue
                                else:
                                    return True
                            if (not self.filter) or (
                                    'retweet' not in wb.keys()):
                                self.weibo.append(wb)
                                self.weibo_id_list.append(wb['id'])
                                self.got_count += 1
                            else:
                                pass
                                # print(u'正在过滤转发微博')
            else:
                return True
        except Exception as e:
            print(str(e))

    def get_pages(self):
        """获取全部微博"""
        since_date = datetime.strptime(self.since_date, '%Y-%m-%d')
        today = datetime.strptime(str(date.today()), '%Y-%m-%d')
        if since_date <= today:
            page_count = self.get_page_count()
            page1 = 0
            random_pages = random.randint(1, 5)
            pages = range(self.start_page, page_count + 1)
            for page in tqdm(pages, desc='Progress'):
                is_end = self.get_one_page(page)
                if is_end:
                    break

                # 通过加入随机等待避免被限制。爬虫速度过快容易被系统限制(一段时间后限
                # 制会自动解除)，加入随机等待模拟人的操作，可降低被系统限制的风险。默
                # 认是每爬取1到5页随机等待6到10秒，如果仍然被限，可适当增加sleep时间
                if (page - page1) % random_pages == 0 and page < page_count:
                    sleep(random.randint(6, 10))
                    page1 = page
                    random_pages = random.randint(1, 5)

    def get_weibo_user_info(self, user_id):
        # 输出微博用户基础信息
        self.user_id = user_id
        self.get_user_info()
        res_pd = pd.DataFrame(self.user.items())
        res_pd = res_pd.set_index(0)
        return res_pd.T

    def get_weibo(self, user_id):
        self.user_id = user_id
        self.get_user_info()
        self.get_pages()
        df = pd.DataFrame(self.weibo)
        df.rename(columns={"user_id": "用户ID", "screen_name": "微博名", "text": "正文", "article_url": "头条文章url", "pics": "原始图片url", "video_url": "视频url", "location": "位置", "created_at": "发布日期", "source":"来源", "attitudes_count": "点赞数", "comments_count": "评论数", "reposts_count": "转发数", "topics": "话题", "at_users": "@用户"}, inplace=True)
        return df


# ==============================================================
# ==============================================================
# ==============================================================

def weibo_user(user_id):
    # 微博账户数据
    return Weibo().get_weibo_user_info(user_id=user_id)


def weibo_list(user_id):
    # 微博数据
    return Weibo().get_weibo(user_id=user_id)


if __name__ == "__main__":
    tmp = weibo_user(user_id="2609084213")
    print(tmp)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/20 0020
# @Author  : justin.郑 3907721@qq.com
# @File    : index_weibo.py
# @Desc    : 获取微博指数

import re
import datetime
import pandas as pd
import requests
import matplotlib.pyplot as plt

from gopup.index.cons import index_weibo_headers  # 伪装游览器, 必备

plt.rcParams["font.sans-serif"] = ["SimHei"]  # 显示中文标签


def _get_items(word="股票"):
    url = "https://data.weibo.com/index/ajax/newindex/searchword"
    payload = {"word": word}
    res = requests.post(url, data=payload, headers=index_weibo_headers)
    return {word: re.findall(r"\d+", res.json()["html"])[0]}


def _get_index_data(wid, time_type):
    url = "http://data.weibo.com/index/ajax/newindex/getchartdata"
    data = {
        "wid": wid,
        "dateGroup": time_type,
    }
    res = requests.get(url, params=data, headers=index_weibo_headers)
    json_df = res.json()
    data = {
        "index": json_df["data"][0]["trend"]["x"],
        "value": json_df["data"][0]["trend"]["s"],
    }
    df = pd.DataFrame(data)
    return df


def _process_index(index):
    now = datetime.datetime.now()
    curr_year = now.year
    curr_date = "%04d%02d%02d" % (now.year, now.month, now.day)
    if "月" in index:
        tmp = index.replace("日", "").split("月")
        date = "%04d%02d%02d" % (curr_year, int(tmp[0]), int(tmp[1]))
        if date > curr_date:
            date = "%04d%02d%02d" % (curr_year - 1, int(tmp[0]), int(tmp[1]))
        return date
    return index


def weibo_index(word="python", time_type="3month"):
    """
    :param word: str
    :param time_type: str 1hour, 1day, 1month, 3month
    :return:
    """
    try:
        dict_keyword = _get_items(word)
        df_list = []
        for keyword, wid in dict_keyword.items():
            df = _get_index_data(wid, time_type)
            if df is not None:
                df.columns = ["index", keyword]
                df["index"] = df["index"].apply(lambda x: _process_index(x))
                df.set_index("index", inplace=True)
                df_list.append(df)
        if len(df_list) > 0:
            df = pd.concat(df_list, axis=1)
            if time_type == "1hour" or "1day":
                df.index = pd.to_datetime(df.index)
            else:
                df.index = pd.to_datetime(df.index, format="%Y%m%d")
            return df
    except:
        return None


if __name__ == "__main__":
    df_index = weibo_index(word="疫情", time_type="3month")
    print(df_index)
    df_index.plot()
    plt.show()


 




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/19 0019
# @Author  : justin.郑 3907721@qq.com
# @File    : utils_pass.py
# @Desc    : 验证通过工具

import os
import pandas as pd


def set_token(token):
    df = pd.DataFrame([token], columns=['token'])
    user_home = os.path.expanduser('~')
    fp = os.path.join(user_home, 'gp.csv')
    df.to_csv(fp, index=False)


def get_token():
    user_home = os.path.expanduser('~')
    fp = os.path.join(user_home, 'gp.csv')
    if os.path.exists(fp):
        df = pd.read_csv(fp)
        return str(df.loc[0]['token'])
    else:
        print('请设置gopup的token凭证码，如果没有请访问http://www.gopup.cn注册申请')
        return None

